/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataDatadogUserConfig extends cdktf.TerraformMetaArguments {
    /**
    * When true, `filter` string is exact matched against the user's `email`, followed by `name` attribute. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/data-sources/user#exact_match DataDatadogUser#exact_match}
    */
    readonly exactMatch?: boolean | cdktf.IResolvable;
    /**
    * Filter all users by the given string.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/data-sources/user#filter DataDatadogUser#filter}
    */
    readonly filter: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/data-sources/user#id DataDatadogUser#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/data-sources/user datadog_user}
*/
export declare class DataDatadogUser extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "datadog_user";
    /**
    * Generates CDKTF code for importing a DataDatadogUser resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataDatadogUser to import
    * @param importFromId The id of the existing DataDatadogUser that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/data-sources/user#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataDatadogUser to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/data-sources/user datadog_user} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataDatadogUserConfig
    */
    constructor(scope: Construct, id: string, config: DataDatadogUserConfig);
    get createdAt(): string;
    get disabled(): cdktf.IResolvable;
    get email(): string;
    private _exactMatch?;
    get exactMatch(): boolean | cdktf.IResolvable;
    set exactMatch(value: boolean | cdktf.IResolvable);
    resetExactMatch(): void;
    get exactMatchInput(): boolean | cdktf.IResolvable | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    get filterInput(): string | undefined;
    get handle(): string;
    get icon(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get mfaEnabled(): cdktf.IResolvable;
    get modifiedAt(): string;
    get name(): string;
    get serviceAccount(): cdktf.IResolvable;
    get status(): string;
    get title(): string;
    get verified(): cdktf.IResolvable;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
