/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IntegrationGcpConfig extends cdktf.TerraformMetaArguments {
    /**
    * Silence monitors for expected GCE instance shutdowns. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#automute IntegrationGcp#automute}
    */
    readonly automute?: boolean | cdktf.IResolvable;
    /**
    * Your email found in your JSON service account key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#client_email IntegrationGcp#client_email}
    */
    readonly clientEmail: string;
    /**
    * Your ID found in your JSON service account key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#client_id IntegrationGcp#client_id}
    */
    readonly clientId: string;
    /**
    * Tags to filter which Cloud Run revisions are imported into Datadog. Only revisions that meet specified criteria are monitored.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#cloud_run_revision_filters IntegrationGcp#cloud_run_revision_filters}
    */
    readonly cloudRunRevisionFilters?: string[];
    /**
    * Whether Datadog collects cloud security posture management resources from your GCP project. If enabled, requires `resource_collection_enabled` to also be enabled. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#cspm_resource_collection_enabled IntegrationGcp#cspm_resource_collection_enabled}
    */
    readonly cspmResourceCollectionEnabled?: boolean | cdktf.IResolvable;
    /**
    * Limit the GCE instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#host_filters IntegrationGcp#host_filters}
    */
    readonly hostFilters?: string;
    /**
    * When enabled, Datadog scans for all resource change data in your Google Cloud environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#is_resource_change_collection_enabled IntegrationGcp#is_resource_change_collection_enabled}
    */
    readonly isResourceChangeCollectionEnabled?: boolean | cdktf.IResolvable;
    /**
    * When enabled, Datadog will attempt to collect Security Command Center Findings. Note: This requires additional permissions on the service account. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#is_security_command_center_enabled IntegrationGcp#is_security_command_center_enabled}
    */
    readonly isSecurityCommandCenterEnabled?: boolean | cdktf.IResolvable;
    /**
    * Your private key name found in your JSON service account key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#private_key IntegrationGcp#private_key}
    */
    readonly privateKey: string;
    /**
    * Your private key ID found in your JSON service account key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#private_key_id IntegrationGcp#private_key_id}
    */
    readonly privateKeyId: string;
    /**
    * Your Google Cloud project ID found in your JSON service account key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#project_id IntegrationGcp#project_id}
    */
    readonly projectId: string;
    /**
    * When enabled, Datadog scans for all resources in your GCP environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#resource_collection_enabled IntegrationGcp#resource_collection_enabled}
    */
    readonly resourceCollectionEnabled?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp datadog_integration_gcp}
*/
export declare class IntegrationGcp extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_integration_gcp";
    /**
    * Generates CDKTF code for importing a IntegrationGcp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IntegrationGcp to import
    * @param importFromId The id of the existing IntegrationGcp that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IntegrationGcp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/integration_gcp datadog_integration_gcp} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IntegrationGcpConfig
    */
    constructor(scope: Construct, id: string, config: IntegrationGcpConfig);
    private _automute?;
    get automute(): boolean | cdktf.IResolvable;
    set automute(value: boolean | cdktf.IResolvable);
    resetAutomute(): void;
    get automuteInput(): boolean | cdktf.IResolvable | undefined;
    private _clientEmail?;
    get clientEmail(): string;
    set clientEmail(value: string);
    get clientEmailInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    get clientIdInput(): string | undefined;
    private _cloudRunRevisionFilters?;
    get cloudRunRevisionFilters(): string[];
    set cloudRunRevisionFilters(value: string[]);
    resetCloudRunRevisionFilters(): void;
    get cloudRunRevisionFiltersInput(): string[] | undefined;
    private _cspmResourceCollectionEnabled?;
    get cspmResourceCollectionEnabled(): boolean | cdktf.IResolvable;
    set cspmResourceCollectionEnabled(value: boolean | cdktf.IResolvable);
    resetCspmResourceCollectionEnabled(): void;
    get cspmResourceCollectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _hostFilters?;
    get hostFilters(): string;
    set hostFilters(value: string);
    resetHostFilters(): void;
    get hostFiltersInput(): string | undefined;
    get id(): string;
    private _isResourceChangeCollectionEnabled?;
    get isResourceChangeCollectionEnabled(): boolean | cdktf.IResolvable;
    set isResourceChangeCollectionEnabled(value: boolean | cdktf.IResolvable);
    resetIsResourceChangeCollectionEnabled(): void;
    get isResourceChangeCollectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _isSecurityCommandCenterEnabled?;
    get isSecurityCommandCenterEnabled(): boolean | cdktf.IResolvable;
    set isSecurityCommandCenterEnabled(value: boolean | cdktf.IResolvable);
    resetIsSecurityCommandCenterEnabled(): void;
    get isSecurityCommandCenterEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _privateKey?;
    get privateKey(): string;
    set privateKey(value: string);
    get privateKeyInput(): string | undefined;
    private _privateKeyId?;
    get privateKeyId(): string;
    set privateKeyId(value: string);
    get privateKeyIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _resourceCollectionEnabled?;
    get resourceCollectionEnabled(): boolean | cdktf.IResolvable;
    set resourceCollectionEnabled(value: boolean | cdktf.IResolvable);
    resetResourceCollectionEnabled(): void;
    get resourceCollectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
