/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MonitorNotificationRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the monitor notification rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule#name MonitorNotificationRule#name}
    */
    readonly name: string;
    /**
    * List of recipients to notify.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule#recipients MonitorNotificationRule#recipients}
    */
    readonly recipients: string[];
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule#filter MonitorNotificationRule#filter}
    */
    readonly filter: MonitorNotificationRuleFilter;
}
export interface MonitorNotificationRuleFilter {
    /**
    * All tags that target monitors must match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule#tags MonitorNotificationRule#tags}
    */
    readonly tags: string[];
}
export declare function monitorNotificationRuleFilterToTerraform(struct?: MonitorNotificationRuleFilter | cdktf.IResolvable): any;
export declare function monitorNotificationRuleFilterToHclTerraform(struct?: MonitorNotificationRuleFilter | cdktf.IResolvable): any;
export declare class MonitorNotificationRuleFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MonitorNotificationRuleFilter | cdktf.IResolvable | undefined;
    set internalValue(value: MonitorNotificationRuleFilter | cdktf.IResolvable | undefined);
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    get tagsInput(): string[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule datadog_monitor_notification_rule}
*/
export declare class MonitorNotificationRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_monitor_notification_rule";
    /**
    * Generates CDKTF code for importing a MonitorNotificationRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the MonitorNotificationRule to import
    * @param importFromId The id of the existing MonitorNotificationRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the MonitorNotificationRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/monitor_notification_rule datadog_monitor_notification_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MonitorNotificationRuleConfig
    */
    constructor(scope: Construct, id: string, config: MonitorNotificationRuleConfig);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _recipients?;
    get recipients(): string[];
    set recipients(value: string[]);
    get recipientsInput(): string[] | undefined;
    private _filter;
    get filter(): MonitorNotificationRuleFilterOutputReference;
    putFilter(value: MonitorNotificationRuleFilter): void;
    get filterInput(): cdktf.IResolvable | MonitorNotificationRuleFilter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
