/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SyntheticsGlobalVariableConfig extends cdktf.TerraformMetaArguments {
    /**
    * Description of the global variable. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#description SyntheticsGlobalVariable#description}
    */
    readonly description?: string;
    /**
    * If set to true, the global variable is a FIDO variable. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#is_fido SyntheticsGlobalVariable#is_fido}
    */
    readonly isFido?: boolean | cdktf.IResolvable;
    /**
    * If set to true, the global variable is a TOTP variable. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#is_totp SyntheticsGlobalVariable#is_totp}
    */
    readonly isTotp?: boolean | cdktf.IResolvable;
    /**
    * Synthetics global variable name. Must be all uppercase with underscores.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#name SyntheticsGlobalVariable#name}
    */
    readonly name: string;
    /**
    * Id of the Synthetics test to use for a variable from test.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#parse_test_id SyntheticsGlobalVariable#parse_test_id}
    */
    readonly parseTestId?: string;
    /**
    * A list of role identifiers to associate with the Synthetics global variable. **Deprecated.** This field is no longer supported by the Datadog API. Please use `datadog_restriction_policy` instead.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#restricted_roles SyntheticsGlobalVariable#restricted_roles}
    */
    readonly restrictedRoles?: string[];
    /**
    * If set to true, the value of the global variable is hidden. This setting is automatically set to `true` if `is_totp` or `is_fido` is set to `true`. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#secure SyntheticsGlobalVariable#secure}
    */
    readonly secure?: boolean | cdktf.IResolvable;
    /**
    * A list of tags to associate with your synthetics global variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#tags SyntheticsGlobalVariable#tags}
    */
    readonly tags?: string[];
    /**
    * The value of the global variable. Required unless `is_fido` is set to `true`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#value SyntheticsGlobalVariable#value}
    */
    readonly value?: string;
    /**
    * options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#options SyntheticsGlobalVariable#options}
    */
    readonly options?: SyntheticsGlobalVariableOptions[] | cdktf.IResolvable;
    /**
    * parse_test_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#parse_test_options SyntheticsGlobalVariable#parse_test_options}
    */
    readonly parseTestOptions?: SyntheticsGlobalVariableParseTestOptions[] | cdktf.IResolvable;
}
export interface SyntheticsGlobalVariableOptionsTotpParameters {
    /**
    * Number of digits for the OTP. Value must be between 4 and 10.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#digits SyntheticsGlobalVariable#digits}
    */
    readonly digits: number;
    /**
    * Interval for which to refresh the token (in seconds). Value must be between 0 and 999.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#refresh_interval SyntheticsGlobalVariable#refresh_interval}
    */
    readonly refreshInterval: number;
}
export declare function syntheticsGlobalVariableOptionsTotpParametersToTerraform(struct?: SyntheticsGlobalVariableOptionsTotpParameters | cdktf.IResolvable): any;
export declare function syntheticsGlobalVariableOptionsTotpParametersToHclTerraform(struct?: SyntheticsGlobalVariableOptionsTotpParameters | cdktf.IResolvable): any;
export declare class SyntheticsGlobalVariableOptionsTotpParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SyntheticsGlobalVariableOptionsTotpParameters | cdktf.IResolvable | undefined;
    set internalValue(value: SyntheticsGlobalVariableOptionsTotpParameters | cdktf.IResolvable | undefined);
    private _digits?;
    get digits(): number;
    set digits(value: number);
    get digitsInput(): number | undefined;
    private _refreshInterval?;
    get refreshInterval(): number;
    set refreshInterval(value: number);
    get refreshIntervalInput(): number | undefined;
}
export declare class SyntheticsGlobalVariableOptionsTotpParametersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SyntheticsGlobalVariableOptionsTotpParameters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SyntheticsGlobalVariableOptionsTotpParametersOutputReference;
}
export interface SyntheticsGlobalVariableOptions {
    /**
    * totp_parameters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#totp_parameters SyntheticsGlobalVariable#totp_parameters}
    */
    readonly totpParameters?: SyntheticsGlobalVariableOptionsTotpParameters[] | cdktf.IResolvable;
}
export declare function syntheticsGlobalVariableOptionsToTerraform(struct?: SyntheticsGlobalVariableOptions | cdktf.IResolvable): any;
export declare function syntheticsGlobalVariableOptionsToHclTerraform(struct?: SyntheticsGlobalVariableOptions | cdktf.IResolvable): any;
export declare class SyntheticsGlobalVariableOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SyntheticsGlobalVariableOptions | cdktf.IResolvable | undefined;
    set internalValue(value: SyntheticsGlobalVariableOptions | cdktf.IResolvable | undefined);
    private _totpParameters;
    get totpParameters(): SyntheticsGlobalVariableOptionsTotpParametersList;
    putTotpParameters(value: SyntheticsGlobalVariableOptionsTotpParameters[] | cdktf.IResolvable): void;
    resetTotpParameters(): void;
    get totpParametersInput(): cdktf.IResolvable | SyntheticsGlobalVariableOptionsTotpParameters[] | undefined;
}
export declare class SyntheticsGlobalVariableOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SyntheticsGlobalVariableOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SyntheticsGlobalVariableOptionsOutputReference;
}
export interface SyntheticsGlobalVariableParseTestOptionsParser {
    /**
    * Type of parser to extract the value. Valid values are `raw`, `json_path`, `regex`, `x_path`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#type SyntheticsGlobalVariable#type}
    */
    readonly type: string;
    /**
    * Value for the parser to use, required for type `json_path` or `regex`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#value SyntheticsGlobalVariable#value}
    */
    readonly value?: string;
}
export declare function syntheticsGlobalVariableParseTestOptionsParserToTerraform(struct?: SyntheticsGlobalVariableParseTestOptionsParser | cdktf.IResolvable): any;
export declare function syntheticsGlobalVariableParseTestOptionsParserToHclTerraform(struct?: SyntheticsGlobalVariableParseTestOptionsParser | cdktf.IResolvable): any;
export declare class SyntheticsGlobalVariableParseTestOptionsParserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SyntheticsGlobalVariableParseTestOptionsParser | cdktf.IResolvable | undefined;
    set internalValue(value: SyntheticsGlobalVariableParseTestOptionsParser | cdktf.IResolvable | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class SyntheticsGlobalVariableParseTestOptionsParserList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SyntheticsGlobalVariableParseTestOptionsParser[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SyntheticsGlobalVariableParseTestOptionsParserOutputReference;
}
export interface SyntheticsGlobalVariableParseTestOptions {
    /**
    * Required when type = `http_header`. Defines the header to use to extract the value
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#field SyntheticsGlobalVariable#field}
    */
    readonly field?: string;
    /**
    * When type is `local_variable`, name of the local variable to use to extract the value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#local_variable_name SyntheticsGlobalVariable#local_variable_name}
    */
    readonly localVariableName?: string;
    /**
    * Defines the source to use to extract the value. Valid values are `http_body`, `http_header`, `http_status_code`, `local_variable`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#type SyntheticsGlobalVariable#type}
    */
    readonly type: string;
    /**
    * parser block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#parser SyntheticsGlobalVariable#parser}
    */
    readonly parser?: SyntheticsGlobalVariableParseTestOptionsParser[] | cdktf.IResolvable;
}
export declare function syntheticsGlobalVariableParseTestOptionsToTerraform(struct?: SyntheticsGlobalVariableParseTestOptions | cdktf.IResolvable): any;
export declare function syntheticsGlobalVariableParseTestOptionsToHclTerraform(struct?: SyntheticsGlobalVariableParseTestOptions | cdktf.IResolvable): any;
export declare class SyntheticsGlobalVariableParseTestOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SyntheticsGlobalVariableParseTestOptions | cdktf.IResolvable | undefined;
    set internalValue(value: SyntheticsGlobalVariableParseTestOptions | cdktf.IResolvable | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
    private _localVariableName?;
    get localVariableName(): string;
    set localVariableName(value: string);
    resetLocalVariableName(): void;
    get localVariableNameInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _parser;
    get parser(): SyntheticsGlobalVariableParseTestOptionsParserList;
    putParser(value: SyntheticsGlobalVariableParseTestOptionsParser[] | cdktf.IResolvable): void;
    resetParser(): void;
    get parserInput(): cdktf.IResolvable | SyntheticsGlobalVariableParseTestOptionsParser[] | undefined;
}
export declare class SyntheticsGlobalVariableParseTestOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SyntheticsGlobalVariableParseTestOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SyntheticsGlobalVariableParseTestOptionsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable datadog_synthetics_global_variable}
*/
export declare class SyntheticsGlobalVariable extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_synthetics_global_variable";
    /**
    * Generates CDKTF code for importing a SyntheticsGlobalVariable resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SyntheticsGlobalVariable to import
    * @param importFromId The id of the existing SyntheticsGlobalVariable that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SyntheticsGlobalVariable to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/synthetics_global_variable datadog_synthetics_global_variable} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SyntheticsGlobalVariableConfig
    */
    constructor(scope: Construct, id: string, config: SyntheticsGlobalVariableConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _isFido?;
    get isFido(): boolean | cdktf.IResolvable;
    set isFido(value: boolean | cdktf.IResolvable);
    resetIsFido(): void;
    get isFidoInput(): boolean | cdktf.IResolvable | undefined;
    private _isTotp?;
    get isTotp(): boolean | cdktf.IResolvable;
    set isTotp(value: boolean | cdktf.IResolvable);
    resetIsTotp(): void;
    get isTotpInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _parseTestId?;
    get parseTestId(): string;
    set parseTestId(value: string);
    resetParseTestId(): void;
    get parseTestIdInput(): string | undefined;
    private _restrictedRoles?;
    get restrictedRoles(): string[];
    set restrictedRoles(value: string[]);
    resetRestrictedRoles(): void;
    get restrictedRolesInput(): string[] | undefined;
    private _secure?;
    get secure(): boolean | cdktf.IResolvable;
    set secure(value: boolean | cdktf.IResolvable);
    resetSecure(): void;
    get secureInput(): boolean | cdktf.IResolvable | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
    private _options;
    get options(): SyntheticsGlobalVariableOptionsList;
    putOptions(value: SyntheticsGlobalVariableOptions[] | cdktf.IResolvable): void;
    resetOptions(): void;
    get optionsInput(): cdktf.IResolvable | SyntheticsGlobalVariableOptions[] | undefined;
    private _parseTestOptions;
    get parseTestOptions(): SyntheticsGlobalVariableParseTestOptionsList;
    putParseTestOptions(value: SyntheticsGlobalVariableParseTestOptions[] | cdktf.IResolvable): void;
    resetParseTestOptions(): void;
    get parseTestOptionsInput(): cdktf.IResolvable | SyntheticsGlobalVariableParseTestOptions[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
