/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WebhookCustomVariableConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether the custom variable is secret or not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/webhook_custom_variable#is_secret WebhookCustomVariable#is_secret}
    */
    readonly isSecret: boolean | cdktf.IResolvable;
    /**
    * The name of the variable. It corresponds with `<CUSTOM_VARIABLE_NAME>`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/webhook_custom_variable#name WebhookCustomVariable#name}
    */
    readonly name: string;
    /**
    * The value of the custom variable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/webhook_custom_variable#value WebhookCustomVariable#value}
    */
    readonly value: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/webhook_custom_variable datadog_webhook_custom_variable}
*/
export declare class WebhookCustomVariable extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_webhook_custom_variable";
    /**
    * Generates CDKTF code for importing a WebhookCustomVariable resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WebhookCustomVariable to import
    * @param importFromId The id of the existing WebhookCustomVariable that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/webhook_custom_variable#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WebhookCustomVariable to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/webhook_custom_variable datadog_webhook_custom_variable} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WebhookCustomVariableConfig
    */
    constructor(scope: Construct, id: string, config: WebhookCustomVariableConfig);
    get id(): string;
    private _isSecret?;
    get isSecret(): boolean | cdktf.IResolvable;
    set isSecret(value: boolean | cdktf.IResolvable);
    get isSecretInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
