/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ObservabilityPipelineConfig extends cdktf.TerraformMetaArguments {
    /**
    * The pipeline name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#config ObservabilityPipeline#config}
    */
    readonly config?: ObservabilityPipelineConfigA;
}
export interface ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth {
    /**
    * ARN of the role to assume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#assume_role ObservabilityPipeline#assume_role}
    */
    readonly assumeRole?: string;
    /**
    * AWS region override (if applicable).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#aws_region ObservabilityPipeline#aws_region}
    */
    readonly awsRegion?: string;
    /**
    * External ID for assumed role.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#external_id ObservabilityPipeline#external_id}
    */
    readonly externalId?: string;
    /**
    * Session name for assumed role.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#session_name ObservabilityPipeline#session_name}
    */
    readonly sessionName?: string;
    /**
    * The authentication strategy to use (e.g. aws or basic).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#strategy ObservabilityPipeline#strategy}
    */
    readonly strategy: string;
}
export declare function observabilityPipelineConfigDestinationsAmazonOpensearchAuthToTerraform(struct?: ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsAmazonOpensearchAuthToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsAmazonOpensearchAuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth | cdktf.IResolvable | undefined);
    private _assumeRole?;
    get assumeRole(): string;
    set assumeRole(value: string);
    resetAssumeRole(): void;
    get assumeRoleInput(): string | undefined;
    private _awsRegion?;
    get awsRegion(): string;
    set awsRegion(value: string);
    resetAwsRegion(): void;
    get awsRegionInput(): string | undefined;
    private _externalId?;
    get externalId(): string;
    set externalId(value: string);
    resetExternalId(): void;
    get externalIdInput(): string | undefined;
    private _sessionName?;
    get sessionName(): string;
    set sessionName(value: string);
    resetSessionName(): void;
    get sessionNameInput(): string | undefined;
    private _strategy?;
    get strategy(): string;
    set strategy(value: string);
    get strategyInput(): string | undefined;
}
export interface ObservabilityPipelineConfigDestinationsAmazonOpensearch {
    /**
    * The index or datastream to write logs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#bulk_index ObservabilityPipeline#bulk_index}
    */
    readonly bulkIndex?: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the input for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * auth block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth ObservabilityPipeline#auth}
    */
    readonly auth?: ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth;
}
export declare function observabilityPipelineConfigDestinationsAmazonOpensearchToTerraform(struct?: ObservabilityPipelineConfigDestinationsAmazonOpensearch | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsAmazonOpensearchToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsAmazonOpensearch | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsAmazonOpensearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsAmazonOpensearch | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsAmazonOpensearch | cdktf.IResolvable | undefined);
    private _bulkIndex?;
    get bulkIndex(): string;
    set bulkIndex(value: string);
    resetBulkIndex(): void;
    get bulkIndexInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _auth;
    get auth(): ObservabilityPipelineConfigDestinationsAmazonOpensearchAuthOutputReference;
    putAuth(value: ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth): void;
    resetAuth(): void;
    get authInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsAmazonOpensearchAuth | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsAmazonOpensearchList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsAmazonOpensearch[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsAmazonOpensearchOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsAzureStorage {
    /**
    * Optional prefix for blobs written to the container.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#blob_prefix ObservabilityPipeline#blob_prefix}
    */
    readonly blobPrefix?: string;
    /**
    * The name of the Azure Blob Storage container to store logs in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#container_name ObservabilityPipeline#container_name}
    */
    readonly containerName: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigDestinationsAzureStorageToTerraform(struct?: ObservabilityPipelineConfigDestinationsAzureStorage | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsAzureStorageToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsAzureStorage | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsAzureStorageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsAzureStorage | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsAzureStorage | cdktf.IResolvable | undefined);
    private _blobPrefix?;
    get blobPrefix(): string;
    set blobPrefix(value: string);
    resetBlobPrefix(): void;
    get blobPrefixInput(): string | undefined;
    private _containerName?;
    get containerName(): string;
    set containerName(value: string);
    get containerNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsAzureStorageList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsAzureStorage[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsAzureStorageOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsDatadogLogs {
    /**
    * The unique ID of the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The inputs for the destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigDestinationsDatadogLogsToTerraform(struct?: ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsDatadogLogsToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsDatadogLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsDatadogLogs | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsDatadogLogsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsDatadogLogs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsDatadogLogsOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsElasticsearch {
    /**
    * The Elasticsearch API version to use. Set to `auto` to auto-detect.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#api_version ObservabilityPipeline#api_version}
    */
    readonly apiVersion?: string;
    /**
    * The index or datastream to write logs to in Elasticsearch.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#bulk_index ObservabilityPipeline#bulk_index}
    */
    readonly bulkIndex?: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigDestinationsElasticsearchToTerraform(struct?: ObservabilityPipelineConfigDestinationsElasticsearch | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsElasticsearchToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsElasticsearch | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsElasticsearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsElasticsearch | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsElasticsearch | cdktf.IResolvable | undefined);
    private _apiVersion?;
    get apiVersion(): string;
    set apiVersion(value: string);
    resetApiVersion(): void;
    get apiVersionInput(): string | undefined;
    private _bulkIndex?;
    get bulkIndex(): string;
    set bulkIndex(value: string);
    resetBulkIndex(): void;
    get bulkIndexInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsElasticsearchList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsElasticsearch[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsElasticsearchOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsGoogleChronicleAuth {
    /**
    * Path to the GCP service account key file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#credentials_file ObservabilityPipeline#credentials_file}
    */
    readonly credentialsFile?: string;
}
export declare function observabilityPipelineConfigDestinationsGoogleChronicleAuthToTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleChronicleAuth | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsGoogleChronicleAuthToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleChronicleAuth | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsGoogleChronicleAuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinationsGoogleChronicleAuth | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsGoogleChronicleAuth | cdktf.IResolvable | undefined);
    private _credentialsFile?;
    get credentialsFile(): string;
    set credentialsFile(value: string);
    resetCredentialsFile(): void;
    get credentialsFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigDestinationsGoogleChronicle {
    /**
    * The Google Chronicle customer ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#customer_id ObservabilityPipeline#customer_id}
    */
    readonly customerId?: string;
    /**
    * The encoding format for the logs sent to Chronicle.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#encoding ObservabilityPipeline#encoding}
    */
    readonly encoding?: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The log type metadata associated with the Chronicle destination.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#log_type ObservabilityPipeline#log_type}
    */
    readonly logType?: string;
    /**
    * auth block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth ObservabilityPipeline#auth}
    */
    readonly auth?: ObservabilityPipelineConfigDestinationsGoogleChronicleAuth;
}
export declare function observabilityPipelineConfigDestinationsGoogleChronicleToTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleChronicle | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsGoogleChronicleToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleChronicle | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsGoogleChronicleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsGoogleChronicle | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsGoogleChronicle | cdktf.IResolvable | undefined);
    private _customerId?;
    get customerId(): string;
    set customerId(value: string);
    resetCustomerId(): void;
    get customerIdInput(): string | undefined;
    private _encoding?;
    get encoding(): string;
    set encoding(value: string);
    resetEncoding(): void;
    get encodingInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _logType?;
    get logType(): string;
    set logType(value: string);
    resetLogType(): void;
    get logTypeInput(): string | undefined;
    private _auth;
    get auth(): ObservabilityPipelineConfigDestinationsGoogleChronicleAuthOutputReference;
    putAuth(value: ObservabilityPipelineConfigDestinationsGoogleChronicleAuth): void;
    resetAuth(): void;
    get authInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsGoogleChronicleAuth | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsGoogleChronicleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsGoogleChronicle[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsGoogleChronicleOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth {
    /**
    * Path to the GCP service account key file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#credentials_file ObservabilityPipeline#credentials_file}
    */
    readonly credentialsFile: string;
}
export declare function observabilityPipelineConfigDestinationsGoogleCloudStorageAuthToTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsGoogleCloudStorageAuthToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth | cdktf.IResolvable | undefined);
    private _credentialsFile?;
    get credentialsFile(): string;
    set credentialsFile(value: string);
    get credentialsFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata {
    /**
    * The metadata key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The metadata value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigDestinationsGoogleCloudStorageMetadataToTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsGoogleCloudStorageMetadataToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadataList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadataOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsGoogleCloudStorage {
    /**
    * Access control list setting for objects written to the bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#acl ObservabilityPipeline#acl}
    */
    readonly acl: string;
    /**
    * Name of the GCS bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#bucket ObservabilityPipeline#bucket}
    */
    readonly bucket: string;
    /**
    * Unique identifier for the destination component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * Optional prefix for object keys within the GCS bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_prefix ObservabilityPipeline#key_prefix}
    */
    readonly keyPrefix?: string;
    /**
    * Storage class used for objects stored in GCS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#storage_class ObservabilityPipeline#storage_class}
    */
    readonly storageClass: string;
    /**
    * auth block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth ObservabilityPipeline#auth}
    */
    readonly auth: ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth;
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#metadata ObservabilityPipeline#metadata}
    */
    readonly metadata?: ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigDestinationsGoogleCloudStorageToTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleCloudStorage | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsGoogleCloudStorageToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsGoogleCloudStorage | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsGoogleCloudStorageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsGoogleCloudStorage | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsGoogleCloudStorage | cdktf.IResolvable | undefined);
    private _acl?;
    get acl(): string;
    set acl(value: string);
    get aclInput(): string | undefined;
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _keyPrefix?;
    get keyPrefix(): string;
    set keyPrefix(value: string);
    resetKeyPrefix(): void;
    get keyPrefixInput(): string | undefined;
    private _storageClass?;
    get storageClass(): string;
    set storageClass(value: string);
    get storageClassInput(): string | undefined;
    private _auth;
    get auth(): ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuthOutputReference;
    putAuth(value: ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth): void;
    get authInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsGoogleCloudStorageAuth | undefined;
    private _metadata;
    get metadata(): ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadataList;
    putMetadata(value: ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata[] | cdktf.IResolvable): void;
    resetMetadata(): void;
    get metadataInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsGoogleCloudStorageMetadata[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsGoogleCloudStorageList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsGoogleCloudStorage[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsGoogleCloudStorageOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsMicrosoftSentinel {
    /**
    * Azure AD client ID used for authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#client_id ObservabilityPipeline#client_id}
    */
    readonly clientId: string;
    /**
    * The immutable ID of the Data Collection Rule (DCR).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#dcr_immutable_id ObservabilityPipeline#dcr_immutable_id}
    */
    readonly dcrImmutableId: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The name of the Log Analytics table where logs will be sent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#table ObservabilityPipeline#table}
    */
    readonly table: string;
    /**
    * Azure AD tenant ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tenant_id ObservabilityPipeline#tenant_id}
    */
    readonly tenantId: string;
}
export declare function observabilityPipelineConfigDestinationsMicrosoftSentinelToTerraform(struct?: ObservabilityPipelineConfigDestinationsMicrosoftSentinel | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsMicrosoftSentinelToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsMicrosoftSentinel | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsMicrosoftSentinelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsMicrosoftSentinel | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsMicrosoftSentinel | cdktf.IResolvable | undefined);
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    get clientIdInput(): string | undefined;
    private _dcrImmutableId?;
    get dcrImmutableId(): string;
    set dcrImmutableId(value: string);
    get dcrImmutableIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _table?;
    get table(): string;
    set table(value: string);
    get tableInput(): string | undefined;
    private _tenantId?;
    get tenantId(): string;
    set tenantId(value: string);
    get tenantIdInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsMicrosoftSentinelList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsMicrosoftSentinel[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsMicrosoftSentinelOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsNewRelic {
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The New Relic region.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#region ObservabilityPipeline#region}
    */
    readonly region: string;
}
export declare function observabilityPipelineConfigDestinationsNewRelicToTerraform(struct?: ObservabilityPipelineConfigDestinationsNewRelic | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsNewRelicToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsNewRelic | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsNewRelicOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsNewRelic | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsNewRelic | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsNewRelicList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsNewRelic[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsNewRelicOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsOpensearch {
    /**
    * The index or datastream to write logs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#bulk_index ObservabilityPipeline#bulk_index}
    */
    readonly bulkIndex?: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as input.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigDestinationsOpensearchToTerraform(struct?: ObservabilityPipelineConfigDestinationsOpensearch | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsOpensearchToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsOpensearch | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsOpensearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsOpensearch | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsOpensearch | cdktf.IResolvable | undefined);
    private _bulkIndex?;
    get bulkIndex(): string;
    set bulkIndex(value: string);
    resetBulkIndex(): void;
    get bulkIndexInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsOpensearchList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsOpensearch[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsOpensearchOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsRsyslogTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigDestinationsRsyslogTlsToTerraform(struct?: ObservabilityPipelineConfigDestinationsRsyslogTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsRsyslogTlsToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsRsyslogTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsRsyslogTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinationsRsyslogTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsRsyslogTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigDestinationsRsyslog {
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * Optional socket keepalive duration in milliseconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#keepalive ObservabilityPipeline#keepalive}
    */
    readonly keepalive?: number;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigDestinationsRsyslogTls;
}
export declare function observabilityPipelineConfigDestinationsRsyslogToTerraform(struct?: ObservabilityPipelineConfigDestinationsRsyslog | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsRsyslogToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsRsyslog | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsRsyslogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsRsyslog | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsRsyslog | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _keepalive?;
    get keepalive(): number;
    set keepalive(value: number);
    resetKeepalive(): void;
    get keepaliveInput(): number | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigDestinationsRsyslogTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigDestinationsRsyslogTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsRsyslogTls | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsRsyslogList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsRsyslog[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsRsyslogOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsSentinelOne {
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The SentinelOne region to send logs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#region ObservabilityPipeline#region}
    */
    readonly region: string;
}
export declare function observabilityPipelineConfigDestinationsSentinelOneToTerraform(struct?: ObservabilityPipelineConfigDestinationsSentinelOne | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsSentinelOneToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsSentinelOne | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsSentinelOneOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsSentinelOne | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsSentinelOne | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsSentinelOneList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsSentinelOne[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsSentinelOneOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsSplunkHec {
    /**
    * If `true`, Splunk tries to extract timestamps from incoming log events.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auto_extract_timestamp ObservabilityPipeline#auto_extract_timestamp}
    */
    readonly autoExtractTimestamp?: boolean | cdktf.IResolvable;
    /**
    * Encoding format for log events. Valid values: `json`, `raw_message`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#encoding ObservabilityPipeline#encoding}
    */
    readonly encoding?: string;
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Optional name of the Splunk index where logs are written.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#index ObservabilityPipeline#index}
    */
    readonly index?: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The Splunk sourcetype to assign to log events.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sourcetype ObservabilityPipeline#sourcetype}
    */
    readonly sourcetype?: string;
}
export declare function observabilityPipelineConfigDestinationsSplunkHecToTerraform(struct?: ObservabilityPipelineConfigDestinationsSplunkHec | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsSplunkHecToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsSplunkHec | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsSplunkHecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsSplunkHec | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsSplunkHec | cdktf.IResolvable | undefined);
    private _autoExtractTimestamp?;
    get autoExtractTimestamp(): boolean | cdktf.IResolvable;
    set autoExtractTimestamp(value: boolean | cdktf.IResolvable);
    resetAutoExtractTimestamp(): void;
    get autoExtractTimestampInput(): boolean | cdktf.IResolvable | undefined;
    private _encoding?;
    get encoding(): string;
    set encoding(value: string);
    resetEncoding(): void;
    get encodingInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _index?;
    get index(): string;
    set index(value: string);
    resetIndex(): void;
    get indexInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _sourcetype?;
    get sourcetype(): string;
    set sourcetype(value: string);
    resetSourcetype(): void;
    get sourcetypeInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsSplunkHecList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsSplunkHec[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsSplunkHecOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields {
    /**
    * The header field name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name?: string;
    /**
    * The header field value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value?: string;
}
export declare function observabilityPipelineConfigDestinationsSumoLogicHeaderCustomFieldsToTerraform(struct?: ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsSumoLogicHeaderCustomFieldsToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFieldsOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsSumoLogic {
    /**
    * The output encoding format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#encoding ObservabilityPipeline#encoding}
    */
    readonly encoding?: string;
    /**
    * Optional override for the host name header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#header_host_name ObservabilityPipeline#header_host_name}
    */
    readonly headerHostName?: string;
    /**
    * Optional override for the source category header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#header_source_category ObservabilityPipeline#header_source_category}
    */
    readonly headerSourceCategory?: string;
    /**
    * Optional override for the source name header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#header_source_name ObservabilityPipeline#header_source_name}
    */
    readonly headerSourceName?: string;
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * header_custom_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#header_custom_fields ObservabilityPipeline#header_custom_fields}
    */
    readonly headerCustomFields?: ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigDestinationsSumoLogicToTerraform(struct?: ObservabilityPipelineConfigDestinationsSumoLogic | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsSumoLogicToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsSumoLogic | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsSumoLogicOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsSumoLogic | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsSumoLogic | cdktf.IResolvable | undefined);
    private _encoding?;
    get encoding(): string;
    set encoding(value: string);
    resetEncoding(): void;
    get encodingInput(): string | undefined;
    private _headerHostName?;
    get headerHostName(): string;
    set headerHostName(value: string);
    resetHeaderHostName(): void;
    get headerHostNameInput(): string | undefined;
    private _headerSourceCategory?;
    get headerSourceCategory(): string;
    set headerSourceCategory(value: string);
    resetHeaderSourceCategory(): void;
    get headerSourceCategoryInput(): string | undefined;
    private _headerSourceName?;
    get headerSourceName(): string;
    set headerSourceName(value: string);
    resetHeaderSourceName(): void;
    get headerSourceNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _headerCustomFields;
    get headerCustomFields(): ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFieldsList;
    putHeaderCustomFields(value: ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields[] | cdktf.IResolvable): void;
    resetHeaderCustomFields(): void;
    get headerCustomFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsSumoLogicHeaderCustomFields[] | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsSumoLogicList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsSumoLogic[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsSumoLogicOutputReference;
}
export interface ObservabilityPipelineConfigDestinationsSyslogNgTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigDestinationsSyslogNgTlsToTerraform(struct?: ObservabilityPipelineConfigDestinationsSyslogNgTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsSyslogNgTlsToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsSyslogNgTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsSyslogNgTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinationsSyslogNgTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsSyslogNgTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigDestinationsSyslogNg {
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * Optional socket keepalive duration in milliseconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#keepalive ObservabilityPipeline#keepalive}
    */
    readonly keepalive?: number;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigDestinationsSyslogNgTls;
}
export declare function observabilityPipelineConfigDestinationsSyslogNgToTerraform(struct?: ObservabilityPipelineConfigDestinationsSyslogNg | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsSyslogNgToHclTerraform(struct?: ObservabilityPipelineConfigDestinationsSyslogNg | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsSyslogNgOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigDestinationsSyslogNg | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinationsSyslogNg | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _keepalive?;
    get keepalive(): number;
    set keepalive(value: number);
    resetKeepalive(): void;
    get keepaliveInput(): number | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigDestinationsSyslogNgTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigDestinationsSyslogNgTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsSyslogNgTls | undefined;
}
export declare class ObservabilityPipelineConfigDestinationsSyslogNgList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigDestinationsSyslogNg[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigDestinationsSyslogNgOutputReference;
}
export interface ObservabilityPipelineConfigDestinations {
    /**
    * amazon_opensearch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#amazon_opensearch ObservabilityPipeline#amazon_opensearch}
    */
    readonly amazonOpensearch?: ObservabilityPipelineConfigDestinationsAmazonOpensearch[] | cdktf.IResolvable;
    /**
    * azure_storage block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#azure_storage ObservabilityPipeline#azure_storage}
    */
    readonly azureStorage?: ObservabilityPipelineConfigDestinationsAzureStorage[] | cdktf.IResolvable;
    /**
    * datadog_logs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#datadog_logs ObservabilityPipeline#datadog_logs}
    */
    readonly datadogLogs?: ObservabilityPipelineConfigDestinationsDatadogLogs[] | cdktf.IResolvable;
    /**
    * elasticsearch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#elasticsearch ObservabilityPipeline#elasticsearch}
    */
    readonly elasticsearch?: ObservabilityPipelineConfigDestinationsElasticsearch[] | cdktf.IResolvable;
    /**
    * google_chronicle block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#google_chronicle ObservabilityPipeline#google_chronicle}
    */
    readonly googleChronicle?: ObservabilityPipelineConfigDestinationsGoogleChronicle[] | cdktf.IResolvable;
    /**
    * google_cloud_storage block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#google_cloud_storage ObservabilityPipeline#google_cloud_storage}
    */
    readonly googleCloudStorage?: ObservabilityPipelineConfigDestinationsGoogleCloudStorage[] | cdktf.IResolvable;
    /**
    * microsoft_sentinel block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#microsoft_sentinel ObservabilityPipeline#microsoft_sentinel}
    */
    readonly microsoftSentinel?: ObservabilityPipelineConfigDestinationsMicrosoftSentinel[] | cdktf.IResolvable;
    /**
    * new_relic block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#new_relic ObservabilityPipeline#new_relic}
    */
    readonly newRelic?: ObservabilityPipelineConfigDestinationsNewRelic[] | cdktf.IResolvable;
    /**
    * opensearch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#opensearch ObservabilityPipeline#opensearch}
    */
    readonly opensearch?: ObservabilityPipelineConfigDestinationsOpensearch[] | cdktf.IResolvable;
    /**
    * rsyslog block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rsyslog ObservabilityPipeline#rsyslog}
    */
    readonly rsyslog?: ObservabilityPipelineConfigDestinationsRsyslog[] | cdktf.IResolvable;
    /**
    * sentinel_one block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sentinel_one ObservabilityPipeline#sentinel_one}
    */
    readonly sentinelOne?: ObservabilityPipelineConfigDestinationsSentinelOne[] | cdktf.IResolvable;
    /**
    * splunk_hec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#splunk_hec ObservabilityPipeline#splunk_hec}
    */
    readonly splunkHec?: ObservabilityPipelineConfigDestinationsSplunkHec[] | cdktf.IResolvable;
    /**
    * sumo_logic block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sumo_logic ObservabilityPipeline#sumo_logic}
    */
    readonly sumoLogic?: ObservabilityPipelineConfigDestinationsSumoLogic[] | cdktf.IResolvable;
    /**
    * syslog_ng block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#syslog_ng ObservabilityPipeline#syslog_ng}
    */
    readonly syslogNg?: ObservabilityPipelineConfigDestinationsSyslogNg[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigDestinationsToTerraform(struct?: ObservabilityPipelineConfigDestinations | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigDestinationsToHclTerraform(struct?: ObservabilityPipelineConfigDestinations | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigDestinationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigDestinations | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigDestinations | cdktf.IResolvable | undefined);
    private _amazonOpensearch;
    get amazonOpensearch(): ObservabilityPipelineConfigDestinationsAmazonOpensearchList;
    putAmazonOpensearch(value: ObservabilityPipelineConfigDestinationsAmazonOpensearch[] | cdktf.IResolvable): void;
    resetAmazonOpensearch(): void;
    get amazonOpensearchInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsAmazonOpensearch[] | undefined;
    private _azureStorage;
    get azureStorage(): ObservabilityPipelineConfigDestinationsAzureStorageList;
    putAzureStorage(value: ObservabilityPipelineConfigDestinationsAzureStorage[] | cdktf.IResolvable): void;
    resetAzureStorage(): void;
    get azureStorageInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsAzureStorage[] | undefined;
    private _datadogLogs;
    get datadogLogs(): ObservabilityPipelineConfigDestinationsDatadogLogsList;
    putDatadogLogs(value: ObservabilityPipelineConfigDestinationsDatadogLogs[] | cdktf.IResolvable): void;
    resetDatadogLogs(): void;
    get datadogLogsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsDatadogLogs[] | undefined;
    private _elasticsearch;
    get elasticsearch(): ObservabilityPipelineConfigDestinationsElasticsearchList;
    putElasticsearch(value: ObservabilityPipelineConfigDestinationsElasticsearch[] | cdktf.IResolvable): void;
    resetElasticsearch(): void;
    get elasticsearchInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsElasticsearch[] | undefined;
    private _googleChronicle;
    get googleChronicle(): ObservabilityPipelineConfigDestinationsGoogleChronicleList;
    putGoogleChronicle(value: ObservabilityPipelineConfigDestinationsGoogleChronicle[] | cdktf.IResolvable): void;
    resetGoogleChronicle(): void;
    get googleChronicleInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsGoogleChronicle[] | undefined;
    private _googleCloudStorage;
    get googleCloudStorage(): ObservabilityPipelineConfigDestinationsGoogleCloudStorageList;
    putGoogleCloudStorage(value: ObservabilityPipelineConfigDestinationsGoogleCloudStorage[] | cdktf.IResolvable): void;
    resetGoogleCloudStorage(): void;
    get googleCloudStorageInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsGoogleCloudStorage[] | undefined;
    private _microsoftSentinel;
    get microsoftSentinel(): ObservabilityPipelineConfigDestinationsMicrosoftSentinelList;
    putMicrosoftSentinel(value: ObservabilityPipelineConfigDestinationsMicrosoftSentinel[] | cdktf.IResolvable): void;
    resetMicrosoftSentinel(): void;
    get microsoftSentinelInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsMicrosoftSentinel[] | undefined;
    private _newRelic;
    get newRelic(): ObservabilityPipelineConfigDestinationsNewRelicList;
    putNewRelic(value: ObservabilityPipelineConfigDestinationsNewRelic[] | cdktf.IResolvable): void;
    resetNewRelic(): void;
    get newRelicInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsNewRelic[] | undefined;
    private _opensearch;
    get opensearch(): ObservabilityPipelineConfigDestinationsOpensearchList;
    putOpensearch(value: ObservabilityPipelineConfigDestinationsOpensearch[] | cdktf.IResolvable): void;
    resetOpensearch(): void;
    get opensearchInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsOpensearch[] | undefined;
    private _rsyslog;
    get rsyslog(): ObservabilityPipelineConfigDestinationsRsyslogList;
    putRsyslog(value: ObservabilityPipelineConfigDestinationsRsyslog[] | cdktf.IResolvable): void;
    resetRsyslog(): void;
    get rsyslogInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsRsyslog[] | undefined;
    private _sentinelOne;
    get sentinelOne(): ObservabilityPipelineConfigDestinationsSentinelOneList;
    putSentinelOne(value: ObservabilityPipelineConfigDestinationsSentinelOne[] | cdktf.IResolvable): void;
    resetSentinelOne(): void;
    get sentinelOneInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsSentinelOne[] | undefined;
    private _splunkHec;
    get splunkHec(): ObservabilityPipelineConfigDestinationsSplunkHecList;
    putSplunkHec(value: ObservabilityPipelineConfigDestinationsSplunkHec[] | cdktf.IResolvable): void;
    resetSplunkHec(): void;
    get splunkHecInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsSplunkHec[] | undefined;
    private _sumoLogic;
    get sumoLogic(): ObservabilityPipelineConfigDestinationsSumoLogicList;
    putSumoLogic(value: ObservabilityPipelineConfigDestinationsSumoLogic[] | cdktf.IResolvable): void;
    resetSumoLogic(): void;
    get sumoLogicInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsSumoLogic[] | undefined;
    private _syslogNg;
    get syslogNg(): ObservabilityPipelineConfigDestinationsSyslogNgList;
    putSyslogNg(value: ObservabilityPipelineConfigDestinationsSyslogNg[] | cdktf.IResolvable): void;
    resetSyslogNg(): void;
    get syslogNgInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinationsSyslogNg[] | undefined;
}
export interface ObservabilityPipelineConfigProcessorsAddEnvVarsVariables {
    /**
    * The target field in the log event.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field: string;
    /**
    * The name of the environment variable to read.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
}
export declare function observabilityPipelineConfigProcessorsAddEnvVarsVariablesToTerraform(struct?: ObservabilityPipelineConfigProcessorsAddEnvVarsVariables | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsAddEnvVarsVariablesToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsAddEnvVarsVariables | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsAddEnvVarsVariablesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsAddEnvVarsVariables | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsAddEnvVarsVariables | cdktf.IResolvable | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    get fieldInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsAddEnvVarsVariablesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsAddEnvVarsVariables[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsAddEnvVarsVariablesOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsAddEnvVars {
    /**
    * The unique identifier for this component. Used to reference this processor in the pipeline.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the input for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * variables block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#variables ObservabilityPipeline#variables}
    */
    readonly variables?: ObservabilityPipelineConfigProcessorsAddEnvVarsVariables[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsAddEnvVarsToTerraform(struct?: ObservabilityPipelineConfigProcessorsAddEnvVars | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsAddEnvVarsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsAddEnvVars | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsAddEnvVarsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsAddEnvVars | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsAddEnvVars | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _variables;
    get variables(): ObservabilityPipelineConfigProcessorsAddEnvVarsVariablesList;
    putVariables(value: ObservabilityPipelineConfigProcessorsAddEnvVarsVariables[] | cdktf.IResolvable): void;
    resetVariables(): void;
    get variablesInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsAddEnvVarsVariables[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsAddEnvVarsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsAddEnvVars[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsAddEnvVarsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsAddFieldsField {
    /**
    * The field name to add.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The value to assign to the field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigProcessorsAddFieldsFieldToTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsAddFieldsFieldToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsAddFieldsFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsAddFieldsField | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsAddFieldsFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsAddFieldsField[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsAddFieldsFieldOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsAddFields {
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * field block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: ObservabilityPipelineConfigProcessorsAddFieldsField[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsAddFieldsToTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsAddFieldsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsAddFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsAddFields | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _field;
    get field(): ObservabilityPipelineConfigProcessorsAddFieldsFieldList;
    putField(value: ObservabilityPipelineConfigProcessorsAddFieldsField[] | cdktf.IResolvable): void;
    resetField(): void;
    get fieldInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsAddFieldsField[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsAddFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsAddFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsAddFieldsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsDedupe {
    /**
    * A list of log field paths to check for duplicates.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#fields ObservabilityPipeline#fields}
    */
    readonly fields: string[];
    /**
    * The unique identifier for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the input for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The deduplication mode to apply to the fields.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#mode ObservabilityPipeline#mode}
    */
    readonly mode: string;
}
export declare function observabilityPipelineConfigProcessorsDedupeToTerraform(struct?: ObservabilityPipelineConfigProcessorsDedupe | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsDedupeToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsDedupe | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsDedupeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsDedupe | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsDedupe | cdktf.IResolvable | undefined);
    private _fields?;
    get fields(): string[];
    set fields(value: string[]);
    get fieldsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsDedupeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsDedupe[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsDedupeOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding {
    /**
    * The `encoding` `delimiter`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#delimiter ObservabilityPipeline#delimiter}
    */
    readonly delimiter?: string;
    /**
    * The `encoding` `includes_headers`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#includes_headers ObservabilityPipeline#includes_headers}
    */
    readonly includesHeaders?: boolean | cdktf.IResolvable;
    /**
    * File encoding format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#type ObservabilityPipeline#type}
    */
    readonly type?: string;
}
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileEncodingToTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileEncodingToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncodingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding | cdktf.IResolvable | undefined);
    private _delimiter?;
    get delimiter(): string;
    set delimiter(value: string);
    resetDelimiter(): void;
    get delimiterInput(): string | undefined;
    private _includesHeaders?;
    get includesHeaders(): boolean | cdktf.IResolvable;
    set includesHeaders(value: boolean | cdktf.IResolvable);
    resetIncludesHeaders(): void;
    get includesHeadersInput(): boolean | cdktf.IResolvable | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey {
    /**
    * The `items` `column`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#column ObservabilityPipeline#column}
    */
    readonly column?: string;
    /**
    * The comparison method (e.g. equals).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#comparison ObservabilityPipeline#comparison}
    */
    readonly comparison?: string;
    /**
    * The `items` `field`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: string;
}
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileKeyToTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileKeyToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableFileKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey | cdktf.IResolvable | undefined);
    private _column?;
    get column(): string;
    set column(value: string);
    resetColumn(): void;
    get columnInput(): string | undefined;
    private _comparison?;
    get comparison(): string;
    set comparison(value: string);
    resetComparison(): void;
    get comparisonInput(): string | undefined;
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableFileKeyList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsEnrichmentTableFileKeyOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema {
    /**
    * The `items` `column`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#column ObservabilityPipeline#column}
    */
    readonly column?: string;
    /**
    * The type of the column (e.g. string, boolean, integer, etc.).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#type ObservabilityPipeline#type}
    */
    readonly type?: string;
}
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileSchemaToTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileSchemaToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchemaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema | cdktf.IResolvable | undefined);
    private _column?;
    get column(): string;
    set column(value: string);
    resetColumn(): void;
    get columnInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchemaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchemaOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsEnrichmentTableFile {
    /**
    * Path to the CSV file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#path ObservabilityPipeline#path}
    */
    readonly path?: string;
    /**
    * encoding block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#encoding ObservabilityPipeline#encoding}
    */
    readonly encoding?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding;
    /**
    * key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key ObservabilityPipeline#key}
    */
    readonly key?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey[] | cdktf.IResolvable;
    /**
    * schema block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#schema ObservabilityPipeline#schema}
    */
    readonly schema?: ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileToTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFile | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsEnrichmentTableFileToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableFile | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableFileOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsEnrichmentTableFile | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFile | cdktf.IResolvable | undefined);
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _encoding;
    get encoding(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncodingOutputReference;
    putEncoding(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding): void;
    resetEncoding(): void;
    get encodingInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsEnrichmentTableFileEncoding | undefined;
    private _key;
    get key(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileKeyList;
    putKey(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey[] | cdktf.IResolvable): void;
    resetKey(): void;
    get keyInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsEnrichmentTableFileKey[] | undefined;
    private _schema;
    get schema(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchemaList;
    putSchema(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema[] | cdktf.IResolvable): void;
    resetSchema(): void;
    get schemaInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsEnrichmentTableFileSchema[] | undefined;
}
export interface ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip {
    /**
    * Path to the IP field in the log.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_field ObservabilityPipeline#key_field}
    */
    readonly keyField?: string;
    /**
    * Locale used to resolve geographical names.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#locale ObservabilityPipeline#locale}
    */
    readonly locale?: string;
    /**
    * Path to the GeoIP database file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#path ObservabilityPipeline#path}
    */
    readonly path?: string;
}
export declare function observabilityPipelineConfigProcessorsEnrichmentTableGeoipToTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsEnrichmentTableGeoipToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableGeoipOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip | cdktf.IResolvable | undefined);
    private _keyField?;
    get keyField(): string;
    set keyField(value: string);
    resetKeyField(): void;
    get keyFieldInput(): string | undefined;
    private _locale?;
    get locale(): string;
    set locale(value: string);
    resetLocale(): void;
    get localeInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
}
export interface ObservabilityPipelineConfigProcessorsEnrichmentTable {
    /**
    * The unique identifier for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the input for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * Path where enrichment results should be stored in the log.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#target ObservabilityPipeline#target}
    */
    readonly target: string;
    /**
    * file block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#file ObservabilityPipeline#file}
    */
    readonly file?: ObservabilityPipelineConfigProcessorsEnrichmentTableFile;
    /**
    * geoip block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#geoip ObservabilityPipeline#geoip}
    */
    readonly geoip?: ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip;
}
export declare function observabilityPipelineConfigProcessorsEnrichmentTableToTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTable | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsEnrichmentTableToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsEnrichmentTable | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsEnrichmentTable | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsEnrichmentTable | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _target?;
    get target(): string;
    set target(value: string);
    get targetInput(): string | undefined;
    private _file;
    get file(): ObservabilityPipelineConfigProcessorsEnrichmentTableFileOutputReference;
    putFile(value: ObservabilityPipelineConfigProcessorsEnrichmentTableFile): void;
    resetFile(): void;
    get fileInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsEnrichmentTableFile | undefined;
    private _geoip;
    get geoip(): ObservabilityPipelineConfigProcessorsEnrichmentTableGeoipOutputReference;
    putGeoip(value: ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip): void;
    resetGeoip(): void;
    get geoipInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsEnrichmentTableGeoip | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsEnrichmentTableList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsEnrichmentTable[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsEnrichmentTableOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsFilter {
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs should pass through the filter. Logs that match this query continue to downstream components; others are dropped.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigProcessorsFilterToTerraform(struct?: ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsFilterToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsFilter | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsFilterList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsFilter[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsFilterOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue {
    /**
    * Name of the log field containing the numeric value to increment the metric by (used only for `increment_by_field`).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: string;
    /**
    * Metric value strategy: `increment_by_one` or `increment_by_field`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#strategy ObservabilityPipeline#strategy}
    */
    readonly strategy: string;
}
export declare function observabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValueToTerraform(struct?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValueToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue | cdktf.IResolvable | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
    private _strategy?;
    get strategy(): string;
    set strategy(value: string);
    get strategyInput(): string | undefined;
}
export interface ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics {
    /**
    * Optional fields used to group the metric series.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#group_by ObservabilityPipeline#group_by}
    */
    readonly groupBy?: string[];
    /**
    * Datadog filter query to match logs for metric generation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * Type of metric to create.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#metric_type ObservabilityPipeline#metric_type}
    */
    readonly metricType: string;
    /**
    * Name of the custom metric to be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue;
}
export declare function observabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsToTerraform(struct?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics | cdktf.IResolvable | undefined);
    private _groupBy?;
    get groupBy(): string[];
    set groupBy(value: string[]);
    resetGroupBy(): void;
    get groupByInput(): string[] | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _metricType?;
    get metricType(): string;
    set metricType(value: string);
    get metricTypeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value;
    get value(): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValueOutputReference;
    putValue(value: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue): void;
    resetValue(): void;
    get valueInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsValue | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the `input` for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * metrics block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#metrics ObservabilityPipeline#metrics}
    */
    readonly metrics?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsGenerateDatadogMetricsToTerraform(struct?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsGenerateDatadogMetricsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _metrics;
    get metrics(): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetricsList;
    putMetrics(value: ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics[] | cdktf.IResolvable): void;
    resetMetrics(): void;
    get metricsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsMetrics[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsOcsfMapperMapping {
    /**
    * Search query for selecting which logs the mapping applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * Predefined library mapping for log transformation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#library_mapping ObservabilityPipeline#library_mapping}
    */
    readonly libraryMapping: string;
}
export declare function observabilityPipelineConfigProcessorsOcsfMapperMappingToTerraform(struct?: ObservabilityPipelineConfigProcessorsOcsfMapperMapping | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsOcsfMapperMappingToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsOcsfMapperMapping | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsOcsfMapperMappingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsOcsfMapperMapping | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsOcsfMapperMapping | cdktf.IResolvable | undefined);
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _libraryMapping?;
    get libraryMapping(): string;
    set libraryMapping(value: string);
    get libraryMappingInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsOcsfMapperMappingList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsOcsfMapperMapping[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsOcsfMapperMappingOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsOcsfMapper {
    /**
    * The unique identifier for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Search query to select logs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * List of component IDs whose output is used as input.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * mapping block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#mapping ObservabilityPipeline#mapping}
    */
    readonly mapping?: ObservabilityPipelineConfigProcessorsOcsfMapperMapping[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsOcsfMapperToTerraform(struct?: ObservabilityPipelineConfigProcessorsOcsfMapper | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsOcsfMapperToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsOcsfMapper | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsOcsfMapperOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsOcsfMapper | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsOcsfMapper | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _mapping;
    get mapping(): ObservabilityPipelineConfigProcessorsOcsfMapperMappingList;
    putMapping(value: ObservabilityPipelineConfigProcessorsOcsfMapperMapping[] | cdktf.IResolvable): void;
    resetMapping(): void;
    get mappingInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsOcsfMapperMapping[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsOcsfMapperList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsOcsfMapper[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsOcsfMapperOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule {
    /**
    * The name of the rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The definition of the Grok rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rule ObservabilityPipeline#rule}
    */
    readonly rule: string;
}
export declare function observabilityPipelineConfigProcessorsParseGrokRulesMatchRuleToTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsParseGrokRulesMatchRuleToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _rule?;
    get rule(): string;
    set rule(value: string);
    get ruleInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRuleOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule {
    /**
    * The name of the helper Grok rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The definition of the helper Grok rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rule ObservabilityPipeline#rule}
    */
    readonly rule: string;
}
export declare function observabilityPipelineConfigProcessorsParseGrokRulesSupportRuleToTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsParseGrokRulesSupportRuleToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _rule?;
    get rule(): string;
    set rule(value: string);
    get ruleInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRuleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRuleOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsParseGrokRules {
    /**
    * The name of the field in the log event to apply the Grok rules to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#source ObservabilityPipeline#source}
    */
    readonly source: string;
    /**
    * match_rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#match_rule ObservabilityPipeline#match_rule}
    */
    readonly matchRule?: ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule[] | cdktf.IResolvable;
    /**
    * support_rule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#support_rule ObservabilityPipeline#support_rule}
    */
    readonly supportRule?: ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsParseGrokRulesToTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrokRules | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsParseGrokRulesToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrokRules | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsParseGrokRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsParseGrokRules | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsParseGrokRules | cdktf.IResolvable | undefined);
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
    private _matchRule;
    get matchRule(): ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRuleList;
    putMatchRule(value: ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule[] | cdktf.IResolvable): void;
    resetMatchRule(): void;
    get matchRuleInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsParseGrokRulesMatchRule[] | undefined;
    private _supportRule;
    get supportRule(): ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRuleList;
    putSupportRule(value: ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule[] | cdktf.IResolvable): void;
    resetSupportRule(): void;
    get supportRuleInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsParseGrokRulesSupportRule[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsParseGrokRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsParseGrokRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsParseGrokRulesOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsParseGrok {
    /**
    * If set to `true`, disables the default Grok rules provided by Datadog.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#disable_library_rules ObservabilityPipeline#disable_library_rules}
    */
    readonly disableLibraryRules?: boolean | cdktf.IResolvable;
    /**
    * A unique identifier for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rules ObservabilityPipeline#rules}
    */
    readonly rules?: ObservabilityPipelineConfigProcessorsParseGrokRules[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsParseGrokToTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrok | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsParseGrokToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsParseGrok | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsParseGrokOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsParseGrok | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsParseGrok | cdktf.IResolvable | undefined);
    private _disableLibraryRules?;
    get disableLibraryRules(): boolean | cdktf.IResolvable;
    set disableLibraryRules(value: boolean | cdktf.IResolvable);
    resetDisableLibraryRules(): void;
    get disableLibraryRulesInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _rules;
    get rules(): ObservabilityPipelineConfigProcessorsParseGrokRulesList;
    putRules(value: ObservabilityPipelineConfigProcessorsParseGrokRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsParseGrokRules[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsParseGrokList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsParseGrok[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsParseGrokOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsParseJson {
    /**
    * The field to parse.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field: string;
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigProcessorsParseJsonToTerraform(struct?: ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsParseJsonToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsParseJsonOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsParseJson | cdktf.IResolvable | undefined);
    private _field?;
    get field(): string;
    set field(value: string);
    get fieldInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsParseJsonList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsParseJson[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsParseJsonOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsQuotaLimit {
    /**
    * Whether to enforce by 'bytes' or 'events'. Valid values are `bytes`, `events`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#enforce ObservabilityPipeline#enforce}
    */
    readonly enforce: string;
    /**
    * The daily quota limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: number;
}
export declare function observabilityPipelineConfigProcessorsQuotaLimitToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaLimitToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaLimit | cdktf.IResolvable | undefined);
    private _enforce?;
    get enforce(): string;
    set enforce(value: string);
    get enforceInput(): string | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    get limitInput(): number | undefined;
}
export interface ObservabilityPipelineConfigProcessorsQuotaOverridesField {
    /**
    * The field name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The field value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigProcessorsQuotaOverridesFieldToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaOverridesFieldToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaOverridesField | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsQuotaOverridesFieldOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsQuotaOverridesLimit {
    /**
    * Whether to enforce by 'bytes' or 'events'. Valid values are `bytes`, `events`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#enforce ObservabilityPipeline#enforce}
    */
    readonly enforce: string;
    /**
    * The daily quota limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: number;
}
export declare function observabilityPipelineConfigProcessorsQuotaOverridesLimitToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaOverridesLimitToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | cdktf.IResolvable | undefined);
    private _enforce?;
    get enforce(): string;
    set enforce(value: string);
    get enforceInput(): string | undefined;
    private _limit?;
    get limit(): number;
    set limit(value: number);
    get limitInput(): number | undefined;
}
export interface ObservabilityPipelineConfigProcessorsQuotaOverrides {
    /**
    * field block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | cdktf.IResolvable;
    /**
    * limit block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit;
}
export declare function observabilityPipelineConfigProcessorsQuotaOverridesToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaOverridesToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuotaOverrides | cdktf.IResolvable | undefined);
    private _field;
    get field(): ObservabilityPipelineConfigProcessorsQuotaOverridesFieldList;
    putField(value: ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | cdktf.IResolvable): void;
    resetField(): void;
    get fieldInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaOverridesField[] | undefined;
    private _limit;
    get limit(): ObservabilityPipelineConfigProcessorsQuotaOverridesLimitOutputReference;
    putLimit(value: ObservabilityPipelineConfigProcessorsQuotaOverridesLimit): void;
    get limitInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaOverridesLimit | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsQuotaOverridesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsQuotaOverrides[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsQuotaOverridesOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsQuota {
    /**
    * Whether to drop events exceeding the limit.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#drop_events ObservabilityPipeline#drop_events}
    */
    readonly dropEvents: boolean | cdktf.IResolvable;
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Whether to ignore when partition fields are missing.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ignore_when_missing_partitions ObservabilityPipeline#ignore_when_missing_partitions}
    */
    readonly ignoreWhenMissingPartitions?: boolean | cdktf.IResolvable;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The name of the quota.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The action to take when the quota is exceeded: `drop`, `no_action`, or `overflow_routing`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#overflow_action ObservabilityPipeline#overflow_action}
    */
    readonly overflowAction?: string;
    /**
    * List of partition fields.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#partition_fields ObservabilityPipeline#partition_fields}
    */
    readonly partitionFields?: string[];
    /**
    * limit block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#limit ObservabilityPipeline#limit}
    */
    readonly limit: ObservabilityPipelineConfigProcessorsQuotaLimit;
    /**
    * overrides block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#overrides ObservabilityPipeline#overrides}
    */
    readonly overrides?: ObservabilityPipelineConfigProcessorsQuotaOverrides[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsQuotaToTerraform(struct?: ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsQuotaToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsQuotaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsQuota | cdktf.IResolvable | undefined);
    private _dropEvents?;
    get dropEvents(): boolean | cdktf.IResolvable;
    set dropEvents(value: boolean | cdktf.IResolvable);
    get dropEventsInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _ignoreWhenMissingPartitions?;
    get ignoreWhenMissingPartitions(): boolean | cdktf.IResolvable;
    set ignoreWhenMissingPartitions(value: boolean | cdktf.IResolvable);
    resetIgnoreWhenMissingPartitions(): void;
    get ignoreWhenMissingPartitionsInput(): boolean | cdktf.IResolvable | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _overflowAction?;
    get overflowAction(): string;
    set overflowAction(value: string);
    resetOverflowAction(): void;
    get overflowActionInput(): string | undefined;
    private _partitionFields?;
    get partitionFields(): string[];
    set partitionFields(value: string[]);
    resetPartitionFields(): void;
    get partitionFieldsInput(): string[] | undefined;
    private _limit;
    get limit(): ObservabilityPipelineConfigProcessorsQuotaLimitOutputReference;
    putLimit(value: ObservabilityPipelineConfigProcessorsQuotaLimit): void;
    get limitInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaLimit | undefined;
    private _overrides;
    get overrides(): ObservabilityPipelineConfigProcessorsQuotaOverridesList;
    putOverrides(value: ObservabilityPipelineConfigProcessorsQuotaOverrides[] | cdktf.IResolvable): void;
    resetOverrides(): void;
    get overridesInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuotaOverrides[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsQuotaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsQuota[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsQuotaOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsReduceMergeStrategies {
    /**
    * The field path in the log event.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#path ObservabilityPipeline#path}
    */
    readonly path: string;
    /**
    * The merge strategy to apply.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#strategy ObservabilityPipeline#strategy}
    */
    readonly strategy: string;
}
export declare function observabilityPipelineConfigProcessorsReduceMergeStrategiesToTerraform(struct?: ObservabilityPipelineConfigProcessorsReduceMergeStrategies | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsReduceMergeStrategiesToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsReduceMergeStrategies | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsReduceMergeStrategiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsReduceMergeStrategies | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsReduceMergeStrategies | cdktf.IResolvable | undefined);
    private _path?;
    get path(): string;
    set path(value: string);
    get pathInput(): string | undefined;
    private _strategy?;
    get strategy(): string;
    set strategy(value: string);
    get strategyInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsReduceMergeStrategiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsReduceMergeStrategies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsReduceMergeStrategiesOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsReduce {
    /**
    * A list of fields used to group log events for merging.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#group_by ObservabilityPipeline#group_by}
    */
    readonly groupBy: string[];
    /**
    * The unique identifier for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the input for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * merge_strategies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#merge_strategies ObservabilityPipeline#merge_strategies}
    */
    readonly mergeStrategies?: ObservabilityPipelineConfigProcessorsReduceMergeStrategies[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsReduceToTerraform(struct?: ObservabilityPipelineConfigProcessorsReduce | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsReduceToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsReduce | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsReduceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsReduce | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsReduce | cdktf.IResolvable | undefined);
    private _groupBy?;
    get groupBy(): string[];
    set groupBy(value: string[]);
    get groupByInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _mergeStrategies;
    get mergeStrategies(): ObservabilityPipelineConfigProcessorsReduceMergeStrategiesList;
    putMergeStrategies(value: ObservabilityPipelineConfigProcessorsReduceMergeStrategies[] | cdktf.IResolvable): void;
    resetMergeStrategies(): void;
    get mergeStrategiesInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsReduceMergeStrategies[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsReduceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsReduce[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsReduceOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsRemoveFields {
    /**
    * List of fields to remove from the events.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#fields ObservabilityPipeline#fields}
    */
    readonly fields: string[];
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
}
export declare function observabilityPipelineConfigProcessorsRemoveFieldsToTerraform(struct?: ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsRemoveFieldsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsRemoveFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsRemoveFields | cdktf.IResolvable | undefined);
    private _fields?;
    get fields(): string[];
    set fields(value: string[]);
    get fieldsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsRemoveFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsRemoveFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsRemoveFieldsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsRenameFieldsField {
    /**
    * Destination field name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#destination ObservabilityPipeline#destination}
    */
    readonly destination: string;
    /**
    * Whether to keep the original field.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#preserve_source ObservabilityPipeline#preserve_source}
    */
    readonly preserveSource: boolean | cdktf.IResolvable;
    /**
    * Source field to rename.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#source ObservabilityPipeline#source}
    */
    readonly source: string;
}
export declare function observabilityPipelineConfigProcessorsRenameFieldsFieldToTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsRenameFieldsFieldToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsFieldOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsRenameFieldsField | cdktf.IResolvable | undefined);
    private _destination?;
    get destination(): string;
    set destination(value: string);
    get destinationInput(): string | undefined;
    private _preserveSource?;
    get preserveSource(): boolean | cdktf.IResolvable;
    set preserveSource(value: boolean | cdktf.IResolvable);
    get preserveSourceInput(): boolean | cdktf.IResolvable | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsFieldList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsRenameFieldsField[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsRenameFieldsFieldOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsRenameFields {
    /**
    * The unique ID of the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * The inputs for the processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * field block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#field ObservabilityPipeline#field}
    */
    readonly field?: ObservabilityPipelineConfigProcessorsRenameFieldsField[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsRenameFieldsToTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsRenameFieldsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsRenameFields | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _field;
    get field(): ObservabilityPipelineConfigProcessorsRenameFieldsFieldList;
    putField(value: ObservabilityPipelineConfigProcessorsRenameFieldsField[] | cdktf.IResolvable): void;
    resetField(): void;
    get fieldInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsRenameFieldsField[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsRenameFieldsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsRenameFields[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsRenameFieldsOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsSample {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (for example, as the `input` to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The percentage of logs to sample.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#percentage ObservabilityPipeline#percentage}
    */
    readonly percentage?: number;
    /**
    * Number of events to sample (1 in N).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rate ObservabilityPipeline#rate}
    */
    readonly rate?: number;
}
export declare function observabilityPipelineConfigProcessorsSampleToTerraform(struct?: ObservabilityPipelineConfigProcessorsSample | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSampleToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSample | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSampleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsSample | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSample | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _percentage?;
    get percentage(): number;
    set percentage(value: number);
    resetPercentage(): void;
    get percentageInput(): number | undefined;
    private _rate?;
    get rate(): number;
    set rate(value: number);
    resetRate(): void;
    get rateInput(): number | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsSampleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsSample[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsSampleOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions {
    /**
    * A list of keywords to match near the sensitive pattern.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#keywords ObservabilityPipeline#keywords}
    */
    readonly keywords?: string[];
    /**
    * Maximum number of tokens between a keyword and a sensitive value match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#proximity ObservabilityPipeline#proximity}
    */
    readonly proximity?: number;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptionsToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptionsToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions | cdktf.IResolvable | undefined);
    private _keywords?;
    get keywords(): string[];
    set keywords(value: string[]);
    resetKeywords(): void;
    get keywordsInput(): string[] | undefined;
    private _proximity?;
    get proximity(): number;
    set proximity(value: number);
    resetProximity(): void;
    get proximityInput(): number | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash {
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHashToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHashToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHashOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash | cdktf.IResolvable | undefined);
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact {
    /**
    * Number of characters to keep.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#characters ObservabilityPipeline#characters}
    */
    readonly characters?: number;
    /**
    * Direction from which to keep characters: `first` or `last`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#direction ObservabilityPipeline#direction}
    */
    readonly direction?: string;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedactToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedactToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedactOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact | cdktf.IResolvable | undefined);
    private _characters?;
    get characters(): number;
    set characters(value: number);
    resetCharacters(): void;
    get charactersInput(): number | undefined;
    private _direction?;
    get direction(): string;
    set direction(value: string);
    resetDirection(): void;
    get directionInput(): string | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact {
    /**
    * Replacement string for redacted values (e.g., `***`).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#replace ObservabilityPipeline#replace}
    */
    readonly replace?: string;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedactToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedactToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedactOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact | cdktf.IResolvable | undefined);
    private _replace?;
    get replace(): string;
    set replace(value: string);
    resetReplace(): void;
    get replaceInput(): string | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch {
    /**
    * hash block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#hash ObservabilityPipeline#hash}
    */
    readonly hash?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash;
    /**
    * partial_redact block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#partial_redact ObservabilityPipeline#partial_redact}
    */
    readonly partialRedact?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact;
    /**
    * redact block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#redact ObservabilityPipeline#redact}
    */
    readonly redact?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch | cdktf.IResolvable | undefined);
    private _hash;
    get hash(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHashOutputReference;
    putHash(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash): void;
    get hashInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchHash | undefined;
    private _partialRedact;
    get partialRedact(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedactOutputReference;
    putPartialRedact(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact): void;
    resetPartialRedact(): void;
    get partialRedactInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchPartialRedact | undefined;
    private _redact;
    get redact(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedactOutputReference;
    putRedact(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact): void;
    resetRedact(): void;
    get redactInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchRedact | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom {
    /**
    * A regular expression used to detect sensitive values. Must be a valid regex.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rule ObservabilityPipeline#rule}
    */
    readonly rule?: string;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustomToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustomToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustomOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom | cdktf.IResolvable | undefined);
    private _rule?;
    get rule(): string;
    set rule(value: string);
    resetRule(): void;
    get ruleInput(): string | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary {
    /**
    * Identifier for a predefined pattern from the sensitive data scanner pattern library.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether to augment the pattern with recommended keywords (optional).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#use_recommended_keywords ObservabilityPipeline#use_recommended_keywords}
    */
    readonly useRecommendedKeywords?: boolean | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibraryToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibraryToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibraryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _useRecommendedKeywords?;
    get useRecommendedKeywords(): boolean | cdktf.IResolvable;
    set useRecommendedKeywords(value: boolean | cdktf.IResolvable);
    resetUseRecommendedKeywords(): void;
    get useRecommendedKeywordsInput(): boolean | cdktf.IResolvable | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern {
    /**
    * custom block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#custom ObservabilityPipeline#custom}
    */
    readonly custom?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom;
    /**
    * library block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#library ObservabilityPipeline#library}
    */
    readonly library?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern | cdktf.IResolvable | undefined);
    private _custom;
    get custom(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustomOutputReference;
    putCustom(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom): void;
    resetCustom(): void;
    get customInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternCustom | undefined;
    private _library;
    get library(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibraryOutputReference;
    putLibrary(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary): void;
    resetLibrary(): void;
    get libraryInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternLibrary | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude {
    /**
    * The fields to exclude from scanning.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#fields ObservabilityPipeline#fields}
    */
    readonly fields?: string[];
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExcludeToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExcludeToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExcludeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude | cdktf.IResolvable | undefined);
    private _fields?;
    get fields(): string[];
    set fields(value: string[]);
    resetFields(): void;
    get fieldsInput(): string[] | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude {
    /**
    * The fields to include in scanning.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#fields ObservabilityPipeline#fields}
    */
    readonly fields?: string[];
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeIncludeToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeIncludeToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeIncludeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude | cdktf.IResolvable | undefined);
    private _fields?;
    get fields(): string[];
    set fields(value: string[]);
    resetFields(): void;
    get fieldsInput(): string[] | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope {
    /**
    * Scan all fields.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#all ObservabilityPipeline#all}
    */
    readonly all?: boolean | cdktf.IResolvable;
    /**
    * exclude block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#exclude ObservabilityPipeline#exclude}
    */
    readonly exclude?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude;
    /**
    * include block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope | cdktf.IResolvable | undefined);
    private _all?;
    get all(): boolean | cdktf.IResolvable;
    set all(value: boolean | cdktf.IResolvable);
    resetAll(): void;
    get allInput(): boolean | cdktf.IResolvable | undefined;
    private _exclude;
    get exclude(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExcludeOutputReference;
    putExclude(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude): void;
    resetExclude(): void;
    get excludeInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeExclude | undefined;
    private _include;
    get include(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeIncludeOutputReference;
    putInclude(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude): void;
    resetInclude(): void;
    get includeInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeInclude | undefined;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules {
    /**
    * A name identifying the rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name?: string;
    /**
    * Tags assigned to this rule for filtering and classification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tags ObservabilityPipeline#tags}
    */
    readonly tags?: string[];
    /**
    * keyword_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#keyword_options ObservabilityPipeline#keyword_options}
    */
    readonly keywordOptions?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions;
    /**
    * on_match block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#on_match ObservabilityPipeline#on_match}
    */
    readonly onMatch?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch;
    /**
    * pattern block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#pattern ObservabilityPipeline#pattern}
    */
    readonly pattern?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern;
    /**
    * scope block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#scope ObservabilityPipeline#scope}
    */
    readonly scope?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerRulesToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _keywordOptions;
    get keywordOptions(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptionsOutputReference;
    putKeywordOptions(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions): void;
    resetKeywordOptions(): void;
    get keywordOptionsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesKeywordOptions | undefined;
    private _onMatch;
    get onMatch(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatchOutputReference;
    putOnMatch(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch): void;
    resetOnMatch(): void;
    get onMatchInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOnMatch | undefined;
    private _pattern;
    get pattern(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPatternOutputReference;
    putPattern(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern): void;
    resetPattern(): void;
    get patternInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesPattern | undefined;
    private _scope;
    get scope(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScopeOutputReference;
    putScope(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope): void;
    resetScope(): void;
    get scopeInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesScope | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsSensitiveDataScanner {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the `input` for this component.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rules ObservabilityPipeline#rules}
    */
    readonly rules?: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerToTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScanner | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsSensitiveDataScannerToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsSensitiveDataScanner | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsSensitiveDataScanner | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsSensitiveDataScanner | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _rules;
    get rules(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerRulesList;
    putRules(value: ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScannerRules[] | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsSensitiveDataScannerList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsSensitiveDataScanner[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsSensitiveDataScannerOutputReference;
}
export interface ObservabilityPipelineConfigProcessorsThrottle {
    /**
    * Optional list of fields used to group events before applying throttling.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#group_by ObservabilityPipeline#group_by}
    */
    readonly groupBy?: string[];
    /**
    * The unique identifier for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A Datadog search query used to determine which logs this processor targets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#include ObservabilityPipeline#include}
    */
    readonly include: string;
    /**
    * A list of component IDs whose output is used as the input for this processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#inputs ObservabilityPipeline#inputs}
    */
    readonly inputs: string[];
    /**
    * The number of events to allow before throttling is applied.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#threshold ObservabilityPipeline#threshold}
    */
    readonly threshold: number;
    /**
    * The time window in seconds over which the threshold applies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#window ObservabilityPipeline#window}
    */
    readonly window: number;
}
export declare function observabilityPipelineConfigProcessorsThrottleToTerraform(struct?: ObservabilityPipelineConfigProcessorsThrottle | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsThrottleToHclTerraform(struct?: ObservabilityPipelineConfigProcessorsThrottle | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsThrottleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigProcessorsThrottle | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessorsThrottle | cdktf.IResolvable | undefined);
    private _groupBy?;
    get groupBy(): string[];
    set groupBy(value: string[]);
    resetGroupBy(): void;
    get groupByInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _include?;
    get include(): string;
    set include(value: string);
    get includeInput(): string | undefined;
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    get inputsInput(): string[] | undefined;
    private _threshold?;
    get threshold(): number;
    set threshold(value: number);
    get thresholdInput(): number | undefined;
    private _window?;
    get window(): number;
    set window(value: number);
    get windowInput(): number | undefined;
}
export declare class ObservabilityPipelineConfigProcessorsThrottleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigProcessorsThrottle[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigProcessorsThrottleOutputReference;
}
export interface ObservabilityPipelineConfigProcessors {
    /**
    * add_env_vars block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#add_env_vars ObservabilityPipeline#add_env_vars}
    */
    readonly addEnvVars?: ObservabilityPipelineConfigProcessorsAddEnvVars[] | cdktf.IResolvable;
    /**
    * add_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#add_fields ObservabilityPipeline#add_fields}
    */
    readonly addFields?: ObservabilityPipelineConfigProcessorsAddFields[] | cdktf.IResolvable;
    /**
    * dedupe block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#dedupe ObservabilityPipeline#dedupe}
    */
    readonly dedupe?: ObservabilityPipelineConfigProcessorsDedupe[] | cdktf.IResolvable;
    /**
    * enrichment_table block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#enrichment_table ObservabilityPipeline#enrichment_table}
    */
    readonly enrichmentTable?: ObservabilityPipelineConfigProcessorsEnrichmentTable[] | cdktf.IResolvable;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#filter ObservabilityPipeline#filter}
    */
    readonly filter?: ObservabilityPipelineConfigProcessorsFilter[] | cdktf.IResolvable;
    /**
    * generate_datadog_metrics block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#generate_datadog_metrics ObservabilityPipeline#generate_datadog_metrics}
    */
    readonly generateDatadogMetrics?: ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics[] | cdktf.IResolvable;
    /**
    * ocsf_mapper block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ocsf_mapper ObservabilityPipeline#ocsf_mapper}
    */
    readonly ocsfMapper?: ObservabilityPipelineConfigProcessorsOcsfMapper[] | cdktf.IResolvable;
    /**
    * parse_grok block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#parse_grok ObservabilityPipeline#parse_grok}
    */
    readonly parseGrok?: ObservabilityPipelineConfigProcessorsParseGrok[] | cdktf.IResolvable;
    /**
    * parse_json block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#parse_json ObservabilityPipeline#parse_json}
    */
    readonly parseJson?: ObservabilityPipelineConfigProcessorsParseJson[] | cdktf.IResolvable;
    /**
    * quota block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#quota ObservabilityPipeline#quota}
    */
    readonly quota?: ObservabilityPipelineConfigProcessorsQuota[] | cdktf.IResolvable;
    /**
    * reduce block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#reduce ObservabilityPipeline#reduce}
    */
    readonly reduce?: ObservabilityPipelineConfigProcessorsReduce[] | cdktf.IResolvable;
    /**
    * remove_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#remove_fields ObservabilityPipeline#remove_fields}
    */
    readonly removeFields?: ObservabilityPipelineConfigProcessorsRemoveFields[] | cdktf.IResolvable;
    /**
    * rename_fields block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rename_fields ObservabilityPipeline#rename_fields}
    */
    readonly renameFields?: ObservabilityPipelineConfigProcessorsRenameFields[] | cdktf.IResolvable;
    /**
    * sample block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sample ObservabilityPipeline#sample}
    */
    readonly sample?: ObservabilityPipelineConfigProcessorsSample[] | cdktf.IResolvable;
    /**
    * sensitive_data_scanner block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sensitive_data_scanner ObservabilityPipeline#sensitive_data_scanner}
    */
    readonly sensitiveDataScanner?: ObservabilityPipelineConfigProcessorsSensitiveDataScanner[] | cdktf.IResolvable;
    /**
    * throttle block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#throttle ObservabilityPipeline#throttle}
    */
    readonly throttle?: ObservabilityPipelineConfigProcessorsThrottle[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigProcessorsToTerraform(struct?: ObservabilityPipelineConfigProcessors | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigProcessorsToHclTerraform(struct?: ObservabilityPipelineConfigProcessors | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigProcessorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigProcessors | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigProcessors | cdktf.IResolvable | undefined);
    private _addEnvVars;
    get addEnvVars(): ObservabilityPipelineConfigProcessorsAddEnvVarsList;
    putAddEnvVars(value: ObservabilityPipelineConfigProcessorsAddEnvVars[] | cdktf.IResolvable): void;
    resetAddEnvVars(): void;
    get addEnvVarsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsAddEnvVars[] | undefined;
    private _addFields;
    get addFields(): ObservabilityPipelineConfigProcessorsAddFieldsList;
    putAddFields(value: ObservabilityPipelineConfigProcessorsAddFields[] | cdktf.IResolvable): void;
    resetAddFields(): void;
    get addFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsAddFields[] | undefined;
    private _dedupe;
    get dedupe(): ObservabilityPipelineConfigProcessorsDedupeList;
    putDedupe(value: ObservabilityPipelineConfigProcessorsDedupe[] | cdktf.IResolvable): void;
    resetDedupe(): void;
    get dedupeInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsDedupe[] | undefined;
    private _enrichmentTable;
    get enrichmentTable(): ObservabilityPipelineConfigProcessorsEnrichmentTableList;
    putEnrichmentTable(value: ObservabilityPipelineConfigProcessorsEnrichmentTable[] | cdktf.IResolvable): void;
    resetEnrichmentTable(): void;
    get enrichmentTableInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsEnrichmentTable[] | undefined;
    private _filter;
    get filter(): ObservabilityPipelineConfigProcessorsFilterList;
    putFilter(value: ObservabilityPipelineConfigProcessorsFilter[] | cdktf.IResolvable): void;
    resetFilter(): void;
    get filterInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsFilter[] | undefined;
    private _generateDatadogMetrics;
    get generateDatadogMetrics(): ObservabilityPipelineConfigProcessorsGenerateDatadogMetricsList;
    putGenerateDatadogMetrics(value: ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics[] | cdktf.IResolvable): void;
    resetGenerateDatadogMetrics(): void;
    get generateDatadogMetricsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsGenerateDatadogMetrics[] | undefined;
    private _ocsfMapper;
    get ocsfMapper(): ObservabilityPipelineConfigProcessorsOcsfMapperList;
    putOcsfMapper(value: ObservabilityPipelineConfigProcessorsOcsfMapper[] | cdktf.IResolvable): void;
    resetOcsfMapper(): void;
    get ocsfMapperInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsOcsfMapper[] | undefined;
    private _parseGrok;
    get parseGrok(): ObservabilityPipelineConfigProcessorsParseGrokList;
    putParseGrok(value: ObservabilityPipelineConfigProcessorsParseGrok[] | cdktf.IResolvable): void;
    resetParseGrok(): void;
    get parseGrokInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsParseGrok[] | undefined;
    private _parseJson;
    get parseJson(): ObservabilityPipelineConfigProcessorsParseJsonList;
    putParseJson(value: ObservabilityPipelineConfigProcessorsParseJson[] | cdktf.IResolvable): void;
    resetParseJson(): void;
    get parseJsonInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsParseJson[] | undefined;
    private _quota;
    get quota(): ObservabilityPipelineConfigProcessorsQuotaList;
    putQuota(value: ObservabilityPipelineConfigProcessorsQuota[] | cdktf.IResolvable): void;
    resetQuota(): void;
    get quotaInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsQuota[] | undefined;
    private _reduce;
    get reduce(): ObservabilityPipelineConfigProcessorsReduceList;
    putReduce(value: ObservabilityPipelineConfigProcessorsReduce[] | cdktf.IResolvable): void;
    resetReduce(): void;
    get reduceInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsReduce[] | undefined;
    private _removeFields;
    get removeFields(): ObservabilityPipelineConfigProcessorsRemoveFieldsList;
    putRemoveFields(value: ObservabilityPipelineConfigProcessorsRemoveFields[] | cdktf.IResolvable): void;
    resetRemoveFields(): void;
    get removeFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsRemoveFields[] | undefined;
    private _renameFields;
    get renameFields(): ObservabilityPipelineConfigProcessorsRenameFieldsList;
    putRenameFields(value: ObservabilityPipelineConfigProcessorsRenameFields[] | cdktf.IResolvable): void;
    resetRenameFields(): void;
    get renameFieldsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsRenameFields[] | undefined;
    private _sample;
    get sample(): ObservabilityPipelineConfigProcessorsSampleList;
    putSample(value: ObservabilityPipelineConfigProcessorsSample[] | cdktf.IResolvable): void;
    resetSample(): void;
    get sampleInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSample[] | undefined;
    private _sensitiveDataScanner;
    get sensitiveDataScanner(): ObservabilityPipelineConfigProcessorsSensitiveDataScannerList;
    putSensitiveDataScanner(value: ObservabilityPipelineConfigProcessorsSensitiveDataScanner[] | cdktf.IResolvable): void;
    resetSensitiveDataScanner(): void;
    get sensitiveDataScannerInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsSensitiveDataScanner[] | undefined;
    private _throttle;
    get throttle(): ObservabilityPipelineConfigProcessorsThrottleList;
    putThrottle(value: ObservabilityPipelineConfigProcessorsThrottle[] | cdktf.IResolvable): void;
    resetThrottle(): void;
    get throttleInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessorsThrottle[] | undefined;
}
export interface ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth {
    /**
    * The Amazon Resource Name (ARN) of the role to assume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#assume_role ObservabilityPipeline#assume_role}
    */
    readonly assumeRole?: string;
    /**
    * A unique identifier for cross-account role assumption.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#external_id ObservabilityPipeline#external_id}
    */
    readonly externalId?: string;
    /**
    * A session identifier used for logging and tracing the assumed role session.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#session_name ObservabilityPipeline#session_name}
    */
    readonly sessionName?: string;
}
export declare function observabilityPipelineConfigSourcesAmazonDataFirehoseAuthToTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesAmazonDataFirehoseAuthToHclTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth | cdktf.IResolvable | undefined);
    private _assumeRole?;
    get assumeRole(): string;
    set assumeRole(value: string);
    resetAssumeRole(): void;
    get assumeRoleInput(): string | undefined;
    private _externalId?;
    get externalId(): string;
    set externalId(value: string);
    resetExternalId(): void;
    get externalIdInput(): string | undefined;
    private _sessionName?;
    get sessionName(): string;
    set sessionName(value: string);
    resetSessionName(): void;
    get sessionNameInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesAmazonDataFirehoseTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesAmazonDataFirehoseTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesAmazonDataFirehoseTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesAmazonDataFirehose {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * auth block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth ObservabilityPipeline#auth}
    */
    readonly auth?: ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls;
}
export declare function observabilityPipelineConfigSourcesAmazonDataFirehoseToTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonDataFirehose | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesAmazonDataFirehoseToHclTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonDataFirehose | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesAmazonDataFirehoseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesAmazonDataFirehose | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesAmazonDataFirehose | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _auth;
    get auth(): ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuthOutputReference;
    putAuth(value: ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth): void;
    resetAuth(): void;
    get authInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesAmazonDataFirehoseAuth | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesAmazonDataFirehoseTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesAmazonDataFirehoseTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesAmazonDataFirehoseList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesAmazonDataFirehose[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesAmazonDataFirehoseOutputReference;
}
export interface ObservabilityPipelineConfigSourcesAmazonS3Auth {
    /**
    * The Amazon Resource Name (ARN) of the role to assume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#assume_role ObservabilityPipeline#assume_role}
    */
    readonly assumeRole?: string;
    /**
    * A unique identifier for cross-account role assumption.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#external_id ObservabilityPipeline#external_id}
    */
    readonly externalId?: string;
    /**
    * A session identifier used for logging and tracing the assumed role session.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#session_name ObservabilityPipeline#session_name}
    */
    readonly sessionName?: string;
}
export declare function observabilityPipelineConfigSourcesAmazonS3AuthToTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonS3Auth | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesAmazonS3AuthToHclTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonS3Auth | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesAmazonS3AuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesAmazonS3Auth | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesAmazonS3Auth | cdktf.IResolvable | undefined);
    private _assumeRole?;
    get assumeRole(): string;
    set assumeRole(value: string);
    resetAssumeRole(): void;
    get assumeRoleInput(): string | undefined;
    private _externalId?;
    get externalId(): string;
    set externalId(value: string);
    resetExternalId(): void;
    get externalIdInput(): string | undefined;
    private _sessionName?;
    get sessionName(): string;
    set sessionName(value: string);
    resetSessionName(): void;
    get sessionNameInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesAmazonS3Tls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesAmazonS3TlsToTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonS3Tls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesAmazonS3TlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonS3Tls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesAmazonS3TlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesAmazonS3Tls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesAmazonS3Tls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesAmazonS3 {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * AWS region where the S3 bucket resides.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#region ObservabilityPipeline#region}
    */
    readonly region: string;
    /**
    * auth block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth ObservabilityPipeline#auth}
    */
    readonly auth?: ObservabilityPipelineConfigSourcesAmazonS3Auth;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesAmazonS3Tls;
}
export declare function observabilityPipelineConfigSourcesAmazonS3ToTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonS3 | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesAmazonS3ToHclTerraform(struct?: ObservabilityPipelineConfigSourcesAmazonS3 | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesAmazonS3OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesAmazonS3 | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesAmazonS3 | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _auth;
    get auth(): ObservabilityPipelineConfigSourcesAmazonS3AuthOutputReference;
    putAuth(value: ObservabilityPipelineConfigSourcesAmazonS3Auth): void;
    resetAuth(): void;
    get authInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesAmazonS3Auth | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesAmazonS3TlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesAmazonS3Tls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesAmazonS3Tls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesAmazonS3List extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesAmazonS3[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesAmazonS3OutputReference;
}
export interface ObservabilityPipelineConfigSourcesDatadogAgentTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesDatadogAgentTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesDatadogAgentTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesDatadogAgentTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesDatadogAgentTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesDatadogAgent {
    /**
    * The unique ID of the source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesDatadogAgentTls;
}
export declare function observabilityPipelineConfigSourcesDatadogAgentToTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesDatadogAgentToHclTerraform(struct?: ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesDatadogAgentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesDatadogAgent | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesDatadogAgentTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesDatadogAgentTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesDatadogAgentTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesDatadogAgentList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesDatadogAgent[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesDatadogAgentOutputReference;
}
export interface ObservabilityPipelineConfigSourcesFluentBitTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesFluentBitTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesFluentBitTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesFluentBitTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesFluentBitTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesFluentBitTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesFluentBitTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesFluentBitTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesFluentBit {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (for example, as the `input` to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesFluentBitTls;
}
export declare function observabilityPipelineConfigSourcesFluentBitToTerraform(struct?: ObservabilityPipelineConfigSourcesFluentBit | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesFluentBitToHclTerraform(struct?: ObservabilityPipelineConfigSourcesFluentBit | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesFluentBitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesFluentBit | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesFluentBit | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesFluentBitTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesFluentBitTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesFluentBitTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesFluentBitList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesFluentBit[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesFluentBitOutputReference;
}
export interface ObservabilityPipelineConfigSourcesFluentdTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesFluentdTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesFluentdTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesFluentdTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesFluentdTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesFluentdTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesFluentdTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesFluentdTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesFluentd {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (for example, as the `input` to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesFluentdTls;
}
export declare function observabilityPipelineConfigSourcesFluentdToTerraform(struct?: ObservabilityPipelineConfigSourcesFluentd | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesFluentdToHclTerraform(struct?: ObservabilityPipelineConfigSourcesFluentd | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesFluentdOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesFluentd | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesFluentd | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesFluentdTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesFluentdTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesFluentdTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesFluentdList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesFluentd[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesFluentdOutputReference;
}
export interface ObservabilityPipelineConfigSourcesGooglePubsubAuth {
    /**
    * Path to the GCP service account key file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#credentials_file ObservabilityPipeline#credentials_file}
    */
    readonly credentialsFile: string;
}
export declare function observabilityPipelineConfigSourcesGooglePubsubAuthToTerraform(struct?: ObservabilityPipelineConfigSourcesGooglePubsubAuth | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesGooglePubsubAuthToHclTerraform(struct?: ObservabilityPipelineConfigSourcesGooglePubsubAuth | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesGooglePubsubAuthOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesGooglePubsubAuth | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesGooglePubsubAuth | cdktf.IResolvable | undefined);
    private _credentialsFile?;
    get credentialsFile(): string;
    set credentialsFile(value: string);
    get credentialsFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesGooglePubsubTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesGooglePubsubTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesGooglePubsubTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesGooglePubsubTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesGooglePubsubTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesGooglePubsubTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesGooglePubsubTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesGooglePubsubTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesGooglePubsub {
    /**
    * The decoding format used to interpret incoming logs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#decoding ObservabilityPipeline#decoding}
    */
    readonly decoding: string;
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The GCP project ID that owns the Pub/Sub subscription.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#project ObservabilityPipeline#project}
    */
    readonly project: string;
    /**
    * The Pub/Sub subscription name from which messages are consumed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#subscription ObservabilityPipeline#subscription}
    */
    readonly subscription: string;
    /**
    * auth block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth ObservabilityPipeline#auth}
    */
    readonly auth: ObservabilityPipelineConfigSourcesGooglePubsubAuth;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesGooglePubsubTls;
}
export declare function observabilityPipelineConfigSourcesGooglePubsubToTerraform(struct?: ObservabilityPipelineConfigSourcesGooglePubsub | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesGooglePubsubToHclTerraform(struct?: ObservabilityPipelineConfigSourcesGooglePubsub | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesGooglePubsubOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesGooglePubsub | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesGooglePubsub | cdktf.IResolvable | undefined);
    private _decoding?;
    get decoding(): string;
    set decoding(value: string);
    get decodingInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    get projectInput(): string | undefined;
    private _subscription?;
    get subscription(): string;
    set subscription(value: string);
    get subscriptionInput(): string | undefined;
    private _auth;
    get auth(): ObservabilityPipelineConfigSourcesGooglePubsubAuthOutputReference;
    putAuth(value: ObservabilityPipelineConfigSourcesGooglePubsubAuth): void;
    get authInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesGooglePubsubAuth | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesGooglePubsubTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesGooglePubsubTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesGooglePubsubTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesGooglePubsubList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesGooglePubsub[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesGooglePubsubOutputReference;
}
export interface ObservabilityPipelineConfigSourcesHttpClientTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesHttpClientTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesHttpClientTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesHttpClientTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesHttpClientTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesHttpClientTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesHttpClientTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesHttpClientTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesHttpClient {
    /**
    * Optional authentication strategy for HTTP requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth_strategy ObservabilityPipeline#auth_strategy}
    */
    readonly authStrategy?: string;
    /**
    * The decoding format used to interpret incoming logs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#decoding ObservabilityPipeline#decoding}
    */
    readonly decoding: string;
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * The interval (in seconds) between HTTP scrape requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#scrape_interval_secs ObservabilityPipeline#scrape_interval_secs}
    */
    readonly scrapeIntervalSecs?: number;
    /**
    * The timeout (in seconds) for each scrape request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#scrape_timeout_secs ObservabilityPipeline#scrape_timeout_secs}
    */
    readonly scrapeTimeoutSecs?: number;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesHttpClientTls;
}
export declare function observabilityPipelineConfigSourcesHttpClientToTerraform(struct?: ObservabilityPipelineConfigSourcesHttpClient | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesHttpClientToHclTerraform(struct?: ObservabilityPipelineConfigSourcesHttpClient | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesHttpClientOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesHttpClient | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesHttpClient | cdktf.IResolvable | undefined);
    private _authStrategy?;
    get authStrategy(): string;
    set authStrategy(value: string);
    resetAuthStrategy(): void;
    get authStrategyInput(): string | undefined;
    private _decoding?;
    get decoding(): string;
    set decoding(value: string);
    get decodingInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _scrapeIntervalSecs?;
    get scrapeIntervalSecs(): number;
    set scrapeIntervalSecs(value: number);
    resetScrapeIntervalSecs(): void;
    get scrapeIntervalSecsInput(): number | undefined;
    private _scrapeTimeoutSecs?;
    get scrapeTimeoutSecs(): number;
    set scrapeTimeoutSecs(value: number);
    resetScrapeTimeoutSecs(): void;
    get scrapeTimeoutSecsInput(): number | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesHttpClientTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesHttpClientTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesHttpClientTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesHttpClientList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesHttpClient[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesHttpClientOutputReference;
}
export interface ObservabilityPipelineConfigSourcesHttpServerTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesHttpServerTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesHttpServerTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesHttpServerTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesHttpServerTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesHttpServerTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesHttpServerTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesHttpServerTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesHttpServer {
    /**
    * HTTP authentication method. Valid values are `none`, `plain`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#auth_strategy ObservabilityPipeline#auth_strategy}
    */
    readonly authStrategy: string;
    /**
    * The decoding format used to interpret incoming logs. Valid values are `json`, `gelf`, `syslog`, `bytes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#decoding ObservabilityPipeline#decoding}
    */
    readonly decoding: string;
    /**
    * Unique ID for the HTTP server source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesHttpServerTls;
}
export declare function observabilityPipelineConfigSourcesHttpServerToTerraform(struct?: ObservabilityPipelineConfigSourcesHttpServer | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesHttpServerToHclTerraform(struct?: ObservabilityPipelineConfigSourcesHttpServer | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesHttpServerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesHttpServer | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesHttpServer | cdktf.IResolvable | undefined);
    private _authStrategy?;
    get authStrategy(): string;
    set authStrategy(value: string);
    get authStrategyInput(): string | undefined;
    private _decoding?;
    get decoding(): string;
    set decoding(value: string);
    get decodingInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesHttpServerTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesHttpServerTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesHttpServerTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesHttpServerList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesHttpServer[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesHttpServerOutputReference;
}
export interface ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption {
    /**
    * The name of the librdkafka option.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#name ObservabilityPipeline#name}
    */
    readonly name: string;
    /**
    * The value of the librdkafka option.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#value ObservabilityPipeline#value}
    */
    readonly value: string;
}
export declare function observabilityPipelineConfigSourcesKafkaLibrdkafkaOptionToTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaLibrdkafkaOptionToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionOutputReference;
}
export interface ObservabilityPipelineConfigSourcesKafkaSasl {
    /**
    * SASL mechanism to use (e.g., PLAIN, SCRAM-SHA-256, SCRAM-SHA-512). Valid values are `PLAIN`, `SCRAM-SHA-256`, `SCRAM-SHA-512`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#mechanism ObservabilityPipeline#mechanism}
    */
    readonly mechanism?: string;
}
export declare function observabilityPipelineConfigSourcesKafkaSaslToTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaSaslToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaSaslOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafkaSasl | cdktf.IResolvable | undefined);
    private _mechanism?;
    get mechanism(): string;
    set mechanism(value: string);
    resetMechanism(): void;
    get mechanismInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesKafkaTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesKafkaTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafkaTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesKafka {
    /**
    * The Kafka consumer group ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#group_id ObservabilityPipeline#group_id}
    */
    readonly groupId: string;
    /**
    * The unique ID of the source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * A list of Kafka topic names to subscribe to. The source ingests messages from each topic specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#topics ObservabilityPipeline#topics}
    */
    readonly topics: string[];
    /**
    * librdkafka_option block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#librdkafka_option ObservabilityPipeline#librdkafka_option}
    */
    readonly librdkafkaOption?: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | cdktf.IResolvable;
    /**
    * sasl block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sasl ObservabilityPipeline#sasl}
    */
    readonly sasl?: ObservabilityPipelineConfigSourcesKafkaSasl;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesKafkaTls;
}
export declare function observabilityPipelineConfigSourcesKafkaToTerraform(struct?: ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesKafkaToHclTerraform(struct?: ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesKafkaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesKafka | cdktf.IResolvable | undefined);
    private _groupId?;
    get groupId(): string;
    set groupId(value: string);
    get groupIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _topics?;
    get topics(): string[];
    set topics(value: string[]);
    get topicsInput(): string[] | undefined;
    private _librdkafkaOption;
    get librdkafkaOption(): ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOptionList;
    putLibrdkafkaOption(value: ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | cdktf.IResolvable): void;
    resetLibrdkafkaOption(): void;
    get librdkafkaOptionInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafkaLibrdkafkaOption[] | undefined;
    private _sasl;
    get sasl(): ObservabilityPipelineConfigSourcesKafkaSaslOutputReference;
    putSasl(value: ObservabilityPipelineConfigSourcesKafkaSasl): void;
    resetSasl(): void;
    get saslInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafkaSasl | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesKafkaTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesKafkaTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafkaTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesKafkaList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesKafka[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesKafkaOutputReference;
}
export interface ObservabilityPipelineConfigSourcesLogstashTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesLogstashTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesLogstashTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesLogstashTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesLogstashTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesLogstashTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesLogstashTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesLogstashTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesLogstash {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesLogstashTls;
}
export declare function observabilityPipelineConfigSourcesLogstashToTerraform(struct?: ObservabilityPipelineConfigSourcesLogstash | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesLogstashToHclTerraform(struct?: ObservabilityPipelineConfigSourcesLogstash | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesLogstashOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesLogstash | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesLogstash | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesLogstashTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesLogstashTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesLogstashTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesLogstashList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesLogstash[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesLogstashOutputReference;
}
export interface ObservabilityPipelineConfigSourcesRsyslogTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesRsyslogTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesRsyslogTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesRsyslogTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesRsyslogTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesRsyslogTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesRsyslogTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesRsyslogTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesRsyslog {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Protocol used by the syslog source to receive messages.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#mode ObservabilityPipeline#mode}
    */
    readonly mode?: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesRsyslogTls;
}
export declare function observabilityPipelineConfigSourcesRsyslogToTerraform(struct?: ObservabilityPipelineConfigSourcesRsyslog | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesRsyslogToHclTerraform(struct?: ObservabilityPipelineConfigSourcesRsyslog | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesRsyslogOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesRsyslog | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesRsyslog | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesRsyslogTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesRsyslogTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesRsyslogTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesRsyslogList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesRsyslog[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesRsyslogOutputReference;
}
export interface ObservabilityPipelineConfigSourcesSplunkHecTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesSplunkHecTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkHecTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSplunkHecTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkHecTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSplunkHecTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesSplunkHecTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSplunkHecTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesSplunkHec {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesSplunkHecTls;
}
export declare function observabilityPipelineConfigSourcesSplunkHecToTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkHec | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSplunkHecToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkHec | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSplunkHecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesSplunkHec | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSplunkHec | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesSplunkHecTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesSplunkHecTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSplunkHecTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesSplunkHecList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesSplunkHec[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesSplunkHecOutputReference;
}
export interface ObservabilityPipelineConfigSourcesSplunkTcpTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesSplunkTcpTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkTcpTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSplunkTcpTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkTcpTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSplunkTcpTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesSplunkTcpTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSplunkTcpTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesSplunkTcp {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesSplunkTcpTls;
}
export declare function observabilityPipelineConfigSourcesSplunkTcpToTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkTcp | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSplunkTcpToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSplunkTcp | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSplunkTcpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesSplunkTcp | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSplunkTcp | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesSplunkTcpTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesSplunkTcpTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSplunkTcpTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesSplunkTcpList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesSplunkTcp[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesSplunkTcpOutputReference;
}
export interface ObservabilityPipelineConfigSourcesSumoLogic {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function observabilityPipelineConfigSourcesSumoLogicToTerraform(struct?: ObservabilityPipelineConfigSourcesSumoLogic | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSumoLogicToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSumoLogic | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSumoLogicOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesSumoLogic | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSumoLogic | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export declare class ObservabilityPipelineConfigSourcesSumoLogicList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesSumoLogic[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesSumoLogicOutputReference;
}
export interface ObservabilityPipelineConfigSourcesSyslogNgTls {
    /**
    * Path to the Certificate Authority (CA) file used to validate the server’s TLS certificate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#ca_file ObservabilityPipeline#ca_file}
    */
    readonly caFile?: string;
    /**
    * Path to the TLS client certificate file used to authenticate the pipeline component with upstream or downstream services.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#crt_file ObservabilityPipeline#crt_file}
    */
    readonly crtFile?: string;
    /**
    * Path to the private key file associated with the TLS client certificate. Used for mutual TLS authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#key_file ObservabilityPipeline#key_file}
    */
    readonly keyFile?: string;
}
export declare function observabilityPipelineConfigSourcesSyslogNgTlsToTerraform(struct?: ObservabilityPipelineConfigSourcesSyslogNgTls | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSyslogNgTlsToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSyslogNgTls | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSyslogNgTlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSourcesSyslogNgTls | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSyslogNgTls | cdktf.IResolvable | undefined);
    private _caFile?;
    get caFile(): string;
    set caFile(value: string);
    resetCaFile(): void;
    get caFileInput(): string | undefined;
    private _crtFile?;
    get crtFile(): string;
    set crtFile(value: string);
    resetCrtFile(): void;
    get crtFileInput(): string | undefined;
    private _keyFile?;
    get keyFile(): string;
    set keyFile(value: string);
    resetKeyFile(): void;
    get keyFileInput(): string | undefined;
}
export interface ObservabilityPipelineConfigSourcesSyslogNg {
    /**
    * The unique identifier for this component. Used to reference this component in other parts of the pipeline (e.g., as input to downstream components).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#id ObservabilityPipeline#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Protocol used by the syslog source to receive messages.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#mode ObservabilityPipeline#mode}
    */
    readonly mode?: string;
    /**
    * tls block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#tls ObservabilityPipeline#tls}
    */
    readonly tls?: ObservabilityPipelineConfigSourcesSyslogNgTls;
}
export declare function observabilityPipelineConfigSourcesSyslogNgToTerraform(struct?: ObservabilityPipelineConfigSourcesSyslogNg | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesSyslogNgToHclTerraform(struct?: ObservabilityPipelineConfigSourcesSyslogNg | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesSyslogNgOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ObservabilityPipelineConfigSourcesSyslogNg | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSourcesSyslogNg | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _tls;
    get tls(): ObservabilityPipelineConfigSourcesSyslogNgTlsOutputReference;
    putTls(value: ObservabilityPipelineConfigSourcesSyslogNgTls): void;
    resetTls(): void;
    get tlsInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSyslogNgTls | undefined;
}
export declare class ObservabilityPipelineConfigSourcesSyslogNgList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ObservabilityPipelineConfigSourcesSyslogNg[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ObservabilityPipelineConfigSourcesSyslogNgOutputReference;
}
export interface ObservabilityPipelineConfigSources {
    /**
    * amazon_data_firehose block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#amazon_data_firehose ObservabilityPipeline#amazon_data_firehose}
    */
    readonly amazonDataFirehose?: ObservabilityPipelineConfigSourcesAmazonDataFirehose[] | cdktf.IResolvable;
    /**
    * amazon_s3 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#amazon_s3 ObservabilityPipeline#amazon_s3}
    */
    readonly amazonS3?: ObservabilityPipelineConfigSourcesAmazonS3[] | cdktf.IResolvable;
    /**
    * datadog_agent block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#datadog_agent ObservabilityPipeline#datadog_agent}
    */
    readonly datadogAgent?: ObservabilityPipelineConfigSourcesDatadogAgent[] | cdktf.IResolvable;
    /**
    * fluent_bit block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#fluent_bit ObservabilityPipeline#fluent_bit}
    */
    readonly fluentBit?: ObservabilityPipelineConfigSourcesFluentBit[] | cdktf.IResolvable;
    /**
    * fluentd block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#fluentd ObservabilityPipeline#fluentd}
    */
    readonly fluentd?: ObservabilityPipelineConfigSourcesFluentd[] | cdktf.IResolvable;
    /**
    * google_pubsub block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#google_pubsub ObservabilityPipeline#google_pubsub}
    */
    readonly googlePubsub?: ObservabilityPipelineConfigSourcesGooglePubsub[] | cdktf.IResolvable;
    /**
    * http_client block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#http_client ObservabilityPipeline#http_client}
    */
    readonly httpClient?: ObservabilityPipelineConfigSourcesHttpClient[] | cdktf.IResolvable;
    /**
    * http_server block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#http_server ObservabilityPipeline#http_server}
    */
    readonly httpServer?: ObservabilityPipelineConfigSourcesHttpServer[] | cdktf.IResolvable;
    /**
    * kafka block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#kafka ObservabilityPipeline#kafka}
    */
    readonly kafka?: ObservabilityPipelineConfigSourcesKafka[] | cdktf.IResolvable;
    /**
    * logstash block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#logstash ObservabilityPipeline#logstash}
    */
    readonly logstash?: ObservabilityPipelineConfigSourcesLogstash[] | cdktf.IResolvable;
    /**
    * rsyslog block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#rsyslog ObservabilityPipeline#rsyslog}
    */
    readonly rsyslog?: ObservabilityPipelineConfigSourcesRsyslog[] | cdktf.IResolvable;
    /**
    * splunk_hec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#splunk_hec ObservabilityPipeline#splunk_hec}
    */
    readonly splunkHec?: ObservabilityPipelineConfigSourcesSplunkHec[] | cdktf.IResolvable;
    /**
    * splunk_tcp block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#splunk_tcp ObservabilityPipeline#splunk_tcp}
    */
    readonly splunkTcp?: ObservabilityPipelineConfigSourcesSplunkTcp[] | cdktf.IResolvable;
    /**
    * sumo_logic block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sumo_logic ObservabilityPipeline#sumo_logic}
    */
    readonly sumoLogic?: ObservabilityPipelineConfigSourcesSumoLogic[] | cdktf.IResolvable;
    /**
    * syslog_ng block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#syslog_ng ObservabilityPipeline#syslog_ng}
    */
    readonly syslogNg?: ObservabilityPipelineConfigSourcesSyslogNg[] | cdktf.IResolvable;
}
export declare function observabilityPipelineConfigSourcesToTerraform(struct?: ObservabilityPipelineConfigSources | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigSourcesToHclTerraform(struct?: ObservabilityPipelineConfigSources | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigSourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigSources | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigSources | cdktf.IResolvable | undefined);
    private _amazonDataFirehose;
    get amazonDataFirehose(): ObservabilityPipelineConfigSourcesAmazonDataFirehoseList;
    putAmazonDataFirehose(value: ObservabilityPipelineConfigSourcesAmazonDataFirehose[] | cdktf.IResolvable): void;
    resetAmazonDataFirehose(): void;
    get amazonDataFirehoseInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesAmazonDataFirehose[] | undefined;
    private _amazonS3;
    get amazonS3(): ObservabilityPipelineConfigSourcesAmazonS3List;
    putAmazonS3(value: ObservabilityPipelineConfigSourcesAmazonS3[] | cdktf.IResolvable): void;
    resetAmazonS3(): void;
    get amazonS3Input(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesAmazonS3[] | undefined;
    private _datadogAgent;
    get datadogAgent(): ObservabilityPipelineConfigSourcesDatadogAgentList;
    putDatadogAgent(value: ObservabilityPipelineConfigSourcesDatadogAgent[] | cdktf.IResolvable): void;
    resetDatadogAgent(): void;
    get datadogAgentInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesDatadogAgent[] | undefined;
    private _fluentBit;
    get fluentBit(): ObservabilityPipelineConfigSourcesFluentBitList;
    putFluentBit(value: ObservabilityPipelineConfigSourcesFluentBit[] | cdktf.IResolvable): void;
    resetFluentBit(): void;
    get fluentBitInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesFluentBit[] | undefined;
    private _fluentd;
    get fluentd(): ObservabilityPipelineConfigSourcesFluentdList;
    putFluentd(value: ObservabilityPipelineConfigSourcesFluentd[] | cdktf.IResolvable): void;
    resetFluentd(): void;
    get fluentdInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesFluentd[] | undefined;
    private _googlePubsub;
    get googlePubsub(): ObservabilityPipelineConfigSourcesGooglePubsubList;
    putGooglePubsub(value: ObservabilityPipelineConfigSourcesGooglePubsub[] | cdktf.IResolvable): void;
    resetGooglePubsub(): void;
    get googlePubsubInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesGooglePubsub[] | undefined;
    private _httpClient;
    get httpClient(): ObservabilityPipelineConfigSourcesHttpClientList;
    putHttpClient(value: ObservabilityPipelineConfigSourcesHttpClient[] | cdktf.IResolvable): void;
    resetHttpClient(): void;
    get httpClientInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesHttpClient[] | undefined;
    private _httpServer;
    get httpServer(): ObservabilityPipelineConfigSourcesHttpServerList;
    putHttpServer(value: ObservabilityPipelineConfigSourcesHttpServer[] | cdktf.IResolvable): void;
    resetHttpServer(): void;
    get httpServerInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesHttpServer[] | undefined;
    private _kafka;
    get kafka(): ObservabilityPipelineConfigSourcesKafkaList;
    putKafka(value: ObservabilityPipelineConfigSourcesKafka[] | cdktf.IResolvable): void;
    resetKafka(): void;
    get kafkaInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesKafka[] | undefined;
    private _logstash;
    get logstash(): ObservabilityPipelineConfigSourcesLogstashList;
    putLogstash(value: ObservabilityPipelineConfigSourcesLogstash[] | cdktf.IResolvable): void;
    resetLogstash(): void;
    get logstashInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesLogstash[] | undefined;
    private _rsyslog;
    get rsyslog(): ObservabilityPipelineConfigSourcesRsyslogList;
    putRsyslog(value: ObservabilityPipelineConfigSourcesRsyslog[] | cdktf.IResolvable): void;
    resetRsyslog(): void;
    get rsyslogInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesRsyslog[] | undefined;
    private _splunkHec;
    get splunkHec(): ObservabilityPipelineConfigSourcesSplunkHecList;
    putSplunkHec(value: ObservabilityPipelineConfigSourcesSplunkHec[] | cdktf.IResolvable): void;
    resetSplunkHec(): void;
    get splunkHecInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSplunkHec[] | undefined;
    private _splunkTcp;
    get splunkTcp(): ObservabilityPipelineConfigSourcesSplunkTcpList;
    putSplunkTcp(value: ObservabilityPipelineConfigSourcesSplunkTcp[] | cdktf.IResolvable): void;
    resetSplunkTcp(): void;
    get splunkTcpInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSplunkTcp[] | undefined;
    private _sumoLogic;
    get sumoLogic(): ObservabilityPipelineConfigSourcesSumoLogicList;
    putSumoLogic(value: ObservabilityPipelineConfigSourcesSumoLogic[] | cdktf.IResolvable): void;
    resetSumoLogic(): void;
    get sumoLogicInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSumoLogic[] | undefined;
    private _syslogNg;
    get syslogNg(): ObservabilityPipelineConfigSourcesSyslogNgList;
    putSyslogNg(value: ObservabilityPipelineConfigSourcesSyslogNg[] | cdktf.IResolvable): void;
    resetSyslogNg(): void;
    get syslogNgInput(): cdktf.IResolvable | ObservabilityPipelineConfigSourcesSyslogNg[] | undefined;
}
export interface ObservabilityPipelineConfigA {
    /**
    * destinations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#destinations ObservabilityPipeline#destinations}
    */
    readonly destinations?: ObservabilityPipelineConfigDestinations;
    /**
    * processors block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#processors ObservabilityPipeline#processors}
    */
    readonly processors?: ObservabilityPipelineConfigProcessors;
    /**
    * sources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#sources ObservabilityPipeline#sources}
    */
    readonly sources?: ObservabilityPipelineConfigSources;
}
export declare function observabilityPipelineConfigAToTerraform(struct?: ObservabilityPipelineConfigA | cdktf.IResolvable): any;
export declare function observabilityPipelineConfigAToHclTerraform(struct?: ObservabilityPipelineConfigA | cdktf.IResolvable): any;
export declare class ObservabilityPipelineConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ObservabilityPipelineConfigA | cdktf.IResolvable | undefined;
    set internalValue(value: ObservabilityPipelineConfigA | cdktf.IResolvable | undefined);
    private _destinations;
    get destinations(): ObservabilityPipelineConfigDestinationsOutputReference;
    putDestinations(value: ObservabilityPipelineConfigDestinations): void;
    resetDestinations(): void;
    get destinationsInput(): cdktf.IResolvable | ObservabilityPipelineConfigDestinations | undefined;
    private _processors;
    get processors(): ObservabilityPipelineConfigProcessorsOutputReference;
    putProcessors(value: ObservabilityPipelineConfigProcessors): void;
    resetProcessors(): void;
    get processorsInput(): cdktf.IResolvable | ObservabilityPipelineConfigProcessors | undefined;
    private _sources;
    get sources(): ObservabilityPipelineConfigSourcesOutputReference;
    putSources(value: ObservabilityPipelineConfigSources): void;
    resetSources(): void;
    get sourcesInput(): cdktf.IResolvable | ObservabilityPipelineConfigSources | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline datadog_observability_pipeline}
*/
export declare class ObservabilityPipeline extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_observability_pipeline";
    /**
    * Generates CDKTF code for importing a ObservabilityPipeline resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ObservabilityPipeline to import
    * @param importFromId The id of the existing ObservabilityPipeline that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ObservabilityPipeline to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.65.0/docs/resources/observability_pipeline datadog_observability_pipeline} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ObservabilityPipelineConfig
    */
    constructor(scope: Construct, id: string, config: ObservabilityPipelineConfig);
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _config;
    get config(): ObservabilityPipelineConfigAOutputReference;
    putConfig(value: ObservabilityPipelineConfigA): void;
    resetConfig(): void;
    get configInput(): cdktf.IResolvable | ObservabilityPipelineConfigA | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
